<?php
/**
 * Template Name: Contact Template
 *
 * @package Theme_Palace
 * @subpackage Philosophy_Pro
 * @since 1.0
 */
get_header();

$options = philosophy_pro_get_theme_options(); // get theme optionns

$map_enabled     = isset( $options['contact_template_map_enable'] ) ? $options['contact_template_map_enable'] : false;

$address_enabled = isset( $options['enable_contact_template_address'] ) ? $options['enable_contact_template_address'] : false;

$form_enabled    = isset( $options['enable_contact_template_form'] ) ? $options['enable_contact_template_form'] : false;

$section_class = ( $map_enabled && $form_enabled ) ? 'col-2' : 'col-1';

?>
<section id="contact-form" class="<?php echo esc_attr( $section_class ); ?>">
    <?php if ( $map_enabled || $address_enabled ) : ?>
        <div class="column-wrapper">
            <div id="map">
                <?php
                    $map_option = ! empty( $options['contact_template_map_option'] ) ? $options['contact_template_map_option'] : 'shortcode' ; 

                    if( 'shortcode' == $map_option ){
                        if( ! empty( $options['contact_template_map_shortcode'] ) ) {
                            echo do_shortcode( wp_kses_post( $options['contact_template_map_shortcode'] ) );
                        }
                    } else {
                        if( ! empty( $options['contact_template_map_embed'] ) )
                           echo html_entity_decode( $options['contact_template_map_embed'] );
                    }
                ?>
            </div>
            <?php if ( $address_enabled ) : ?>
            <div class="location">
                <?php 
                    $address_text  = ! empty ( $options['contact_template_address_text'] ) ? $options['contact_template_address_text'] : '';
                    $address_value = ! empty ( $options['contact_template_address_value'] ) ? $options['contact_template_address_value'] : '';
                    $email_text    = ! empty ( $options['contact_template_email_text'] ) ? $options['contact_template_email_text'] : '';
                    $email_value   = ! empty ( $options['contact_template_email_value'] ) ? $options['contact_template_email_value'] : '';
                    $phone_text    = ! empty ( $options['contact_template_phone_text'] ) ? $options['contact_template_phone_text'] : '';
                    $phone_value   = ! empty ( $options['contact_template_phone_number'] ) ? $options['contact_template_phone_number'] : '';
                ?>
                <ul class="address-block">
                    <?php 
                        if( ! empty( $address_text ) || !empty( $address_value ) ) : 
                            echo ' <li class="address"><i class="fa fa-map-marker"></i>';
                            if ( ! empty( $address_text ) ) {
                                echo '<label>'. esc_html( $address_text ) .'</label>';
                            }

                            if ( ! empty( $address_value ) ) {
                                echo '<span>'. esc_html( $address_value ) .'</span>';
                            }
                            echo '</li>';
                        endif;

                        if( ! empty( $email_text ) || !empty( $email_value ) ) : 
                            echo '<li class="email"><i class="fa fa-envelope"></i>';
                            if ( ! empty( $email_text ) ) {
                                echo '<label>'. esc_html( $email_text ) .'</label>';
                            }

                            if ( ! empty( $email_value ) ) {
                                echo '<span><a href="mailto:'. esc_url( $email_value ) .'">'. esc_html( $email_value ) .'</a></span>';
                            }
                            echo '</li>';
                        endif;

                        if( ! empty( $phone_text ) || !empty( $phone_value ) ) : 
                            echo '<li class="phone"><i class="fa fa-phone"></i>';
                            if ( ! empty( $phone_text ) ) {
                                echo '<label>'. esc_html( $phone_text ) .'</label>';
                            }

                            if ( ! empty( $phone_value ) ) {
                                echo '<span><a href="tel:'. esc_attr( preg_replace('/\D+/', '', $phone_value ) ) .'">'. esc_html( $phone_value ) .'</a></span>';
                            }
                            echo '</li>';
                        endif;
                        ?>
                </ul>

            </div><!-- .location -->
            <?php endif; ?>
        </div><!-- .column-wrapper-->
    <?php endif; ?>

    <?php if( $form_enabled ) : ?>
        <div class="column-wrapper">
            <div class="form-wrapper">
            <?php 
                $form_shortcode = ! empty( $options['contact_template_form_shortcode'] ) ? $options['contact_template_form_shortcode'] : '';

                if ( ! empty( $form_shortcode ) ) {
                    echo do_shortcode( wp_kses_post( $form_shortcode ) );
                }
            ?>
            </div><!--form-wrapper-->
        </div><!--.column-wrapper-->
    <?php endif; ?>
</section><!--#contacts-->
<?php
get_footer();