<?php
/**
 * Customizer active callbacks
 *
 * @package Theme_Palace
 * @subpackage Philosophy_Pro
 * @since 1.0
 */

if ( ! function_exists( 'philosophy_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'philosophy_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'philosophy_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'philosophy_pro_theme_options[pagination_enable]' )->value();
	}
endif;

/**
 * Homepage Sections 
 */

// Slider active callback functions 

if ( ! function_exists( 'philosophy_pro_is_slider_enable' ) ) :
	/**
	 * Check if slider is enabled.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_slider_enable( $control ) {
		return ( 'static-frontpage' == $control->manager->get_setting( 'philosophy_pro_theme_options[slider_enable]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_is_slider_demo_not_active' ) ) :
	/**
	 * Check if demo slider is active.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_slider_demo_not_active( $control ) {
		return ( philosophy_pro_is_slider_enable( $control ) && 'demo' != $control->manager->get_setting( 'philosophy_pro_theme_options[slider_content_type]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_slider_content_post_active' ) ) :
	/**
	 * Check if post slider is active.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_slider_content_post_active( $control ) {
		return ( philosophy_pro_is_slider_enable( $control ) && 'posts' == $control->manager->get_setting( 'philosophy_pro_theme_options[slider_content_type]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_slider_content_page_active' ) ) :
	/**
	 * Check if page slider is active.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_slider_content_page_active( $control ) {
		return ( philosophy_pro_is_slider_enable( $control ) && 'pages' == $control->manager->get_setting( 'philosophy_pro_theme_options[slider_content_type]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_slider_content_category_active' ) ) :
	/**
	 * Check if category slider is active.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_slider_content_category_active( $control ) {
		return ( philosophy_pro_is_slider_enable( $control ) && 'category' == $control->manager->get_setting( 'philosophy_pro_theme_options[slider_content_type]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_slider_content_custom_active' ) ) :
	/**
	 * Check if custom slider is active.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_slider_content_custom_active( $control ) {
		return ( philosophy_pro_is_slider_enable( $control ) && 'custom' == $control->manager->get_setting( 'philosophy_pro_theme_options[slider_content_type]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_slider_content_custom_or_demo_not_active' ) ) :
	/**
	 * Check if custom slider is active.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_slider_content_custom_or_demo_not_active( $control ) {
		if( philosophy_pro_is_slider_enable( $control ) && ( 'posts' == $control->manager->get_setting( 'philosophy_pro_theme_options[slider_content_type]' )->value() || 'pages' == $control->manager->get_setting( 'philosophy_pro_theme_options[slider_content_type]' )->value() || 'category' == $control->manager->get_setting( 'philosophy_pro_theme_options[slider_content_type]' )->value()) ){

			return true;
		} else{
			return false;
		}
	}
endif;

// About section active callback section
if ( ! function_exists( 'philosophy_pro_is_about_enable' ) ) :
	/**
	 * Check if slider is enabled.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_about_enable( $control ) {
		return ( 'static-frontpage' == $control->manager->get_setting( 'philosophy_pro_theme_options[about_enable]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_is_about_content_demo_inactive' ) ) :
	/**
	 * Check if content demo is inactive in about section.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_about_content_demo_inactive( $control ) {
		return ( philosophy_pro_is_about_enable( $control ) && 'demo' != $control->manager->get_setting( 'philosophy_pro_theme_options[about_content_type]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_is_about_content_post_active' ) ) :
	/**
	 * Check if content post  is active in about section.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_about_content_post_active( $control ) {
		return ( philosophy_pro_is_about_enable( $control ) && 'posts' == $control->manager->get_setting( 'philosophy_pro_theme_options[about_content_type]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_is_about_content_page_active' ) ) :
	/**
	 * Check if content page  is active in about section.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_about_content_page_active( $control ) {
		return ( philosophy_pro_is_about_enable( $control ) && 'pages' == $control->manager->get_setting( 'philosophy_pro_theme_options[about_content_type]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_is_about_content_custom_active' ) ) :
	/**
	 * Check if content custom is active in about section.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_about_content_custom_active( $control ) {
		return ( philosophy_pro_is_about_enable( $control ) && 'custom' == $control->manager->get_setting( 'philosophy_pro_theme_options[about_content_type]' )->value() );
	}
endif;


// Services section active callback functions

if ( ! function_exists( 'philosophy_pro_is_services_enable' ) ) :
	/**
	 * Check if services section is enabled on home page.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_services_enable( $control ) {
		return ( 'static-frontpage' == $control->manager->get_setting( 'philosophy_pro_theme_options[services_enable]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_is_services_left_content_post_active' ) ) :
	/**
	 * Check if content post is active in services left section.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_services_left_content_post_active( $control ) {
		return ( philosophy_pro_is_services_enable( $control ) && 'posts' == $control->manager->get_setting( 'philosophy_pro_theme_options[services_left_content_type]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_is_services_left_content_page_active' ) ) :
	/**
	 * Check if content page is active in services left section.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_services_left_content_page_active( $control ) {
		return ( philosophy_pro_is_services_enable( $control ) && 'pages' == $control->manager->get_setting( 'philosophy_pro_theme_options[services_left_content_type]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_is_services_left_content_custom_active' ) ) :
	/**
	 * Check if content custom is active in services left section.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_services_left_content_custom_active( $control ) {
		return ( philosophy_pro_is_services_enable( $control ) && 'custom' == $control->manager->get_setting( 'philosophy_pro_theme_options[services_left_content_type]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_is_services_left_content_demo_inactive' ) ) :
	/**
	 * Check if content demo is inactive in services left section.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_services_left_content_demo_inactive( $control ) {
		return ( philosophy_pro_is_services_enable( $control ) && 'demo' != $control->manager->get_setting( 'philosophy_pro_theme_options[services_left_content_type]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_is_services_right_content_post_active' ) ) :
	/**
	 * Check if content type posts is active in right section.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_services_right_content_post_active( $control ) {
		if( philosophy_pro_is_services_enable( $control ) && ( 'posts' == $control->manager->get_setting( 'philosophy_pro_theme_options[services_right_content_type]' )->value() ) ){

			return true;
		} else{
			return false;
		}
	}
endif;

if ( ! function_exists( 'philosophy_pro_is_services_right_content_demo_inactive' ) ) :
	/**
	 * Check if content demo is inactive in services right section.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_services_right_content_demo_inactive( $control ) {
		return ( philosophy_pro_is_services_enable( $control ) && 'demo' != $control->manager->get_setting( 'philosophy_pro_theme_options[services_right_content_type]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_is_services_right_content_custom_active' ) ) :
	/**
	 * Check if content custom is active in services right section.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_services_right_content_custom_active( $control ) {
		return ( philosophy_pro_is_services_enable( $control ) && 'custom' == $control->manager->get_setting( 'philosophy_pro_theme_options[services_right_content_type]' )->value() );
	}
endif;

// Counter section active callback function

if ( ! function_exists( 'philosophy_pro_is_counter_active' ) ) :
	/**
	 * Check if counter section is enabled on home page.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_counter_active( $control ) {
		return ( 'static-frontpage' == $control->manager->get_setting( 'philosophy_pro_theme_options[counter_enable]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_is_counter_content_demo_inactive' ) ) :
	/**
	 * Check if demo content type is not active in counter section on home page.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_counter_content_demo_inactive( $control ) {
		return philosophy_pro_is_counter_active( $control ) && ( 'demo' != $control->manager->get_setting( 'philosophy_pro_theme_options[counter_content_type]' )->value() );
	}
endif;

// Active callback function for blogs section
if ( ! function_exists( 'philosophy_pro_is_blogs_active' ) ) :
	/**
	 * Check if blogs section is enabled on home page.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_blogs_active( $control ) {
		return ( 'static-frontpage' == $control->manager->get_setting( 'philosophy_pro_theme_options[blogs_enable]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_blogs_content_post_active' ) ) :
	/**
	 * Check if content post is active in blogs section.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_blogs_content_post_active( $control ) {
		return ( philosophy_pro_is_blogs_active( $control ) && 'posts' == $control->manager->get_setting( 'philosophy_pro_theme_options[blogs_content_type]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_blogs_content_category_active' ) ) :
	/**
	 * Check if content category is active in blogs section.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_blogs_content_category_active( $control ) {
		return ( philosophy_pro_is_blogs_active( $control ) && 'category' == $control->manager->get_setting( 'philosophy_pro_theme_options[blogs_content_type]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_is_blogs_content_demo_inactive' ) ) :
	/**
	 * Check if content demo is inactive in blogs section.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_blogs_content_demo_inactive( $control ) {
		return ( philosophy_pro_is_blogs_active( $control ) && 'demo' != $control->manager->get_setting( 'philosophy_pro_theme_options[blogs_content_type]' )->value() );
	}
endif;

// Active callback function for skills section
if ( ! function_exists( 'philosophy_pro_is_skills_enable' ) ) :
	/**
	 * Check if skills section is enabled on home page.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_skills_enable( $control ) {
		return ( 'static-frontpage' == $control->manager->get_setting( 'philosophy_pro_theme_options[skills_enable]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_is_skills_content_post_active' ) ) :
	/**
	 * Check if content post is active in skills section.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_skills_content_post_active( $control ) {
		return ( philosophy_pro_is_skills_enable( $control ) && 'posts' == $control->manager->get_setting( 'philosophy_pro_theme_options[skills_content_type]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_is_skills_content_page_active' ) ) :
	/**
	 * Check if content page is active in skills section.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function philosophy_pro_is_skills_content_page_active( $control ) {
		return ( philosophy_pro_is_skills_enable( $control ) && 'pages' == $control->manager->get_setting( 'philosophy_pro_theme_options[skills_content_type]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_is_skills_content_custom_active' ) ) :
	/**
	 * Check if content custom is active in skills section.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function philosophy_pro_is_skills_content_custom_active( $control ) {
		return ( philosophy_pro_is_skills_enable( $control ) && 'custom' == $control->manager->get_setting( 'philosophy_pro_theme_options[skills_content_type]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_is_skills_content_demo_inactive' ) ) :
	/**
	 * Check if content demo is inactive in skills section.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_skills_content_demo_inactive( $control ) {
		return ( philosophy_pro_is_skills_enable( $control ) && 'demo' != $control->manager->get_setting( 'philosophy_pro_theme_options[skills_content_type]' )->value() );
	}
endif;

// Active callback for teams section
if ( ! function_exists( 'philosophy_pro_is_teams_enable' ) ) :
	/**
	 * Check if teams section is enabled on home page.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_teams_enable( $control ) {
		return ( 'static-frontpage' == $control->manager->get_setting( 'philosophy_pro_theme_options[teams_enable]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_is_teams_demo_inactive' ) ) :
	/**
	 * Check if content demo is inactive in teams section.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_teams_demo_inactive( $control ) {
		return ( philosophy_pro_is_teams_enable( $control ) && 'demo' != $control->manager->get_setting( 'philosophy_pro_theme_options[teams_content_type]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_is_teams_content_post_active' ) ) :
	/**
	 * Check if content post is active in teams section.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_teams_content_post_active( $control ) {
		return ( philosophy_pro_is_teams_enable( $control ) && 'posts' == $control->manager->get_setting( 'philosophy_pro_theme_options[teams_content_type]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_is_cpt_teams_content_post_active' ) ) :
	/**
	 * Check if tp philosophy teams is active in teams section.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_cpt_teams_content_post_active( $control ) {
		return ( philosophy_pro_is_teams_enable( $control ) && 'tp-philosophy-teams' == $control->manager->get_setting( 'philosophy_pro_theme_options[teams_content_type]' )->value() );
	}
endif;

// Active callback for testimonial section
if ( ! function_exists( 'philosophy_pro_is_testimonial_enable' ) ) :
	/**
	 * Check if testimonial section is enabled on home page.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_testimonial_enable( $control ) {
		return ( 'static-frontpage' == $control->manager->get_setting( 'philosophy_pro_theme_options[testimonial_enable]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_is_testimonial_demo_inactive' ) ) :
	/**
	 * Check if content demo is inactive in testimonial section.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_testimonial_demo_inactive( $control ) {
		return ( philosophy_pro_is_testimonial_enable( $control ) && 'demo' != $control->manager->get_setting( 'philosophy_pro_theme_options[testimonial_content_type]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_is_testimonial_content_post_active' ) ) :
	/**
	 * Check if content post is active in testimonial section.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_testimonial_content_post_active( $control ) {
		return ( philosophy_pro_is_testimonial_enable( $control ) && 'posts' == $control->manager->get_setting( 'philosophy_pro_theme_options[testimonial_content_type]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_is_cpt_testimonial_content_post_active' ) ) :
	/**
	 * Check if cpt content post is active in testimonial section.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_cpt_testimonial_content_post_active( $control ) {
		return ( philosophy_pro_is_testimonial_enable( $control ) && 'tp-philosophy-testimonial' == $control->manager->get_setting( 'philosophy_pro_theme_options[testimonial_content_type]' )->value() );
	}
endif;


if ( ! function_exists( 'philosophy_pro_is_testimonial_content_page_active' ) ) :
	/**
	 * Check if content page is active in testimonial section.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_testimonial_content_page_active( $control ) {
		return ( philosophy_pro_is_testimonial_enable( $control ) && 'page' == $control->manager->get_setting( 'philosophy_pro_theme_options[testimonial_content_type]' )->value() );
	}
endif;


if ( ! function_exists( 'philosophy_pro_is_testimonial_category_active' ) ) :
	/**
	 * Check if content category is active in testimonial section.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_testimonial_category_active( $control ) {
		return ( philosophy_pro_is_testimonial_enable( $control ) && 'category' == $control->manager->get_setting( 'philosophy_pro_theme_options[testimonial_content_type]' )->value() );
	}
endif;


// Active callback for client section
if ( ! function_exists( 'philosophy_pro_is_clients_enable' ) ) :
	/**
	 * Check if client section is enabled on home page.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_clients_enable( $control ) {
		return ( 'static-frontpage' == $control->manager->get_setting( 'philosophy_pro_theme_options[clients_enable]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_is_clients_demo_inactive' ) ) :
	/**
	 * Check if demo content is disabled on client section.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_clients_demo_inactive( $control ) {
		return ( philosophy_pro_is_clients_enable( $control ) && 'demo' != $control->manager->get_setting( 'philosophy_pro_theme_options[clients_content_type]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_is_clients_content_post_active' ) ) :
	/**
	 * Check if content post is active on client section.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_clients_content_post_active( $control ) {
		return ( philosophy_pro_is_clients_enable( $control ) && 'posts' == $control->manager->get_setting( 'philosophy_pro_theme_options[clients_content_type]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_is_clients_content_page_active' ) ) :
	/**
	 * Check if content page is active on client section.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_clients_content_page_active( $control ) {
		return ( philosophy_pro_is_clients_enable( $control ) && 'page' == $control->manager->get_setting( 'philosophy_pro_theme_options[clients_content_type]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_is_clients_category_active' ) ) :
	/**
	 * Check if content category is active on client section.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_clients_category_active( $control ) {
		return ( philosophy_pro_is_clients_enable( $control ) && 'category' == $control->manager->get_setting( 'philosophy_pro_theme_options[clients_content_type]' )->value() );
	}
endif;

// Active callback for work section
if ( ! function_exists( 'philosophy_pro_is_works_enable' ) ) :
	/**
	 * Check if work section is enabled on home page.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_works_enable( $control ) {
		return ( 'static-frontpage' == $control->manager->get_setting( 'philosophy_pro_theme_options[works_enable]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_is_works_content_page_active' ) ) :
	/**
	 * Check if content page is active on work section.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_works_content_page_active( $control ) {
		return ( philosophy_pro_is_works_enable( $control ) && 'page' == $control->manager->get_setting( 'philosophy_pro_theme_options[works_content_type]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_is_works_content_custom_active' ) ) :
	/**
	 * Check if content custom is active on work section.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_works_content_custom_active( $control ) {
		return ( philosophy_pro_is_works_enable( $control ) && 'custom' == $control->manager->get_setting( 'philosophy_pro_theme_options[works_content_type]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_is_works_content_demo_inactive' ) ) :
	/**
	 * Check if content demo is active on work section.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_works_content_demo_inactive( $control ) {
		return ( philosophy_pro_is_works_enable( $control ) && 'demo' != $control->manager->get_setting( 'philosophy_pro_theme_options[works_content_type]' )->value() );
	}
endif;

// Active callback for contact section
if ( ! function_exists( 'philosophy_pro_is_contact_active' ) ) :
	/**
	 * Check if client section is enabled on home page.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_contact_active( $control ) {
		return ( 'static-frontpage' == $control->manager->get_setting( 'philosophy_pro_theme_options[contact_enable]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_is_contact_content_demo_inactive' ) ) :
	/**
	 * Check if content demo is active on contact section.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_contact_content_demo_inactive( $control ) {
		return ( philosophy_pro_is_contact_active( $control ) && 'demo' != $control->manager->get_setting( 'philosophy_pro_theme_options[contact_content_type]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_is_contact_social_link_enable' ) ) :
	/**
	 * Check if social link is active on contact section.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_contact_social_link_enable( $control ) {
		return ( philosophy_pro_is_contact_content_demo_inactive( $control ) &&  $control->manager->get_setting( 'philosophy_pro_theme_options[enable_social_links]' )->value() );
	}
endif;

/**
 * Active callback for footer section
*/

// Check if footer hero content is enabled
if ( ! function_exists( 'philosophy_pro_is_footer_hero_content_enabled' ) ) :
	/**
	 * Check if footer hero content is enabled.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_footer_hero_content_enabled( $control ) {
		return ( $control->manager->get_setting( 'philosophy_pro_theme_options[enable_hero_content]' )->value() );
	}
endif;

/**
 * Active callback for front page content section
*/

// Check if footer hero content is enabled
if ( ! function_exists( 'philosophy_pro_front_page_content_enabled' ) ) :
	/**
	 * Check if front page content is enabled.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_front_page_content_enabled( $control ) {
		return ( $control->manager->get_setting( 'philosophy_pro_theme_options[enable_frontpage_content]' )->value() );
	}
endif;


/**
 * Active callback for team options custom template
*/

// Check if team options is enabled
if ( ! function_exists( 'philosophy_pro_is_team_options_enabled' ) ) :
	/**
	 * Check if front page content is enabled.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_team_options_enabled( $control ) {
		return ( $control->manager->get_setting( 'philosophy_pro_theme_options[enable_team_options]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_team_options_content_category_active' ) ) :
	/**
	 * Check if default category is active on team options.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_team_options_content_category_active( $control ) {
		return ( philosophy_pro_is_team_options_enabled( $control ) && 'category' == $control->manager->get_setting( 'philosophy_pro_theme_options[team_options_content_type]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_team_options_custom_taxonomy_active' ) ) :
	/**
	 * Check if custom category is active on team options.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_team_options_custom_taxonomy_active( $control ) {
		return ( philosophy_pro_is_team_options_enabled( $control ) && 'tp-philosophy-teams' == $control->manager->get_setting( 'philosophy_pro_theme_options[team_options_content_type]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_is_join_team_options_enabled' ) ) :
	/**
	 * Check if join team section is active on custom template.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_join_team_options_enabled( $control ) {
		return ( $control->manager->get_setting( 'philosophy_pro_theme_options[enable_join_team_section]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_is_join_content_post_active' ) ) :
	/**
	 * Check if content post is active on team options.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_join_content_post_active( $control ) {
		return ( philosophy_pro_is_join_team_options_enabled( $control ) && 'post' == $control->manager->get_setting( 'philosophy_pro_theme_options[join_team_content_type]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_is_join_content_page_active' ) ) :
	/**
	 * Check if content page is active on team options.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_join_content_page_active( $control ) {
		return ( philosophy_pro_is_join_team_options_enabled( $control ) && 'page' == $control->manager->get_setting( 'philosophy_pro_theme_options[join_team_content_type]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_is_join_content_custom_active' ) ) :
	/**
	 * Check if content custom is active on team options.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_join_content_custom_active( $control ) {
		return ( philosophy_pro_is_join_team_options_enabled( $control ) && 'custom' == $control->manager->get_setting( 'philosophy_pro_theme_options[join_team_content_type]' )->value() );
	}
endif;

/**
 * Contact template active callback function
 *
 */

if ( ! function_exists( 'philosophy_pro_is_contact_template_map_active' ) ) :
	/**
	 * Check if contact map is enabled on contact template.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function philosophy_pro_is_contact_template_map_active( $control ) {
		return ( $control->manager->get_setting( 'philosophy_pro_theme_options[contact_template_map_enable]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_contact_template_map_embed_active' ) ) :
	/**
	 * Check if embed is enabled on contact template.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function philosophy_pro_contact_template_map_embed_active( $control ) {
		return ( philosophy_pro_is_contact_template_map_active( $control ) && 'embed' == $control->manager->get_setting( 'philosophy_pro_theme_options[contact_template_map_option]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_contact_template_map_shortcode_active' ) ) :
	/**
	 * Check if shortcode is enabled on contact template.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function philosophy_pro_contact_template_map_shortcode_active( $control ) {
		return ( philosophy_pro_is_contact_template_map_active( $control ) && 'shortcode' == $control->manager->get_setting( 'philosophy_pro_theme_options[contact_template_map_option]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_is_contact_template_form_active' ) ) :
	/**
	 * Check if contact form is enabled on contact template.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function philosophy_pro_is_contact_template_form_active( $control ) {
		return ( $control->manager->get_setting( 'philosophy_pro_theme_options[enable_contact_template_form]' )->value() );
	}
endif;

if ( ! function_exists( 'philosophy_pro_contact_address_enabled' ) ) :
	/**
	 * Check if contact address is enabled on contact template.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function philosophy_pro_contact_address_enabled( $control ) {
		return ( $control->manager->get_setting( 'philosophy_pro_theme_options[enable_contact_template_address]' )->value() );
	}
endif;

/**
 *
 * Active callback for our services template
*/

// check if story tempalte service section  is enabled
if ( ! function_exists( 'philosophy_pro_is_story_template_service_enabled' ) ) :
	/**
	 * Check if services section is enabled on story template.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function philosophy_pro_is_story_template_service_enabled( $control ) {
		return ( $control->manager->get_setting( 'philosophy_pro_theme_options[story_template_services_enable]' )->value() );
	}
endif;

// check if story tempalte mission section  is enabled
if ( ! function_exists( 'philosophy_pro_is_story_template_mission_enabled' ) ) :
	/**
	 * Check if mission section is enabled on story template.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function philosophy_pro_is_story_template_mission_enabled( $control ) {
		return ( $control->manager->get_setting( 'philosophy_pro_theme_options[story_template_mission_enable]' )->value() );
	}
endif;

// check if story tempalte mission section page content  is enabled
if ( ! function_exists( 'philosophy_pro_is_story_template_mission_page_enabled' ) ) :
	/**
	 * Check if mission section page content is enabled on story template.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function philosophy_pro_is_story_template_mission_page_enabled( $control ) {
		return ( philosophy_pro_is_story_template_mission_enabled( $control ) && 'page' == $control->manager->get_setting( 'philosophy_pro_theme_options[story_template_mission_content_type]' )->value() );
	}
endif;

// check if story tempalte mission section post content  is enabled
if ( ! function_exists( 'philosophy_pro_is_story_template_mission_post_enabled' ) ) :
	/**
	 * Check if mission section post content is enabled on story template.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function philosophy_pro_is_story_template_mission_post_enabled( $control ) {
		return ( philosophy_pro_is_story_template_mission_enabled( $control ) && 'post' == $control->manager->get_setting( 'philosophy_pro_theme_options[story_template_mission_content_type]' )->value() );
	}
endif;

// check if story tempalte quote section  is enabled
if ( ! function_exists( 'philosophy_pro_is_story_template_quote_enabled' ) ) :
	/**
	 * Check if quote section is enabled on story template.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function philosophy_pro_is_story_template_quote_enabled( $control ) {
		return ( $control->manager->get_setting( 'philosophy_pro_theme_options[story_template_quote_enable]' )->value() );
	}
endif;

/**
 *
 * Story template team section
 *
 * @since 1.0
 */

// check if story tempalte team section  is enabled
if ( ! function_exists( 'philosophy_pro_is_story_template_team_enabled' ) ) :
	/**
	 * Check if team section is enabled on story template.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_story_template_team_enabled( $control ) {
		return ( $control->manager->get_setting( 'philosophy_pro_theme_options[story_template_team_enable]' )->value() );
	}
endif;

// check if story tempalte team section content default post is enabled
if ( ! function_exists( 'philosophy_pro_is_story_template_team_default_post_enabled' ) ) :
	/**
	 * Check if default post is enabled on story template.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_story_template_team_default_post_enabled( $control ) {
		return ( philosophy_pro_is_story_template_team_enabled( $control ) && 'post' == $control->manager->get_setting( 'philosophy_pro_theme_options[story_template_team_content_type]' )->value() );
	}
endif;

// check if story tempalte team section content plugin team post is enabled
if ( ! function_exists( 'philosophy_pro_is_story_template_plugin_team_post_enabled' ) ) :
	/**
	 * Check if plugin team post is enabled on story template.
	 *
	 * @since 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function philosophy_pro_is_story_template_plugin_team_post_enabled( $control ) {
		return ( philosophy_pro_is_story_template_team_enabled( $control ) && 'tp-philosophy-teams' == $control->manager->get_setting( 'philosophy_pro_theme_options[story_template_team_content_type]' )->value() );
	}
endif;