<?php
/**
 * Philosophy Pro about section customizer options
 *
 * @package Theme_Palace
 * @subpackage Philosophy_Pro
 * @since 1.0
 */

// Add about section
$wp_customize->add_section( 'philosophy_pro_about_section', 
	array(
		'title'             => esc_html__( 'About','philosophy-pro' ),
		'description'       => esc_html__( 'about section options.', 'philosophy-pro' ),
		'panel'             => 'philosophy_pro_homepage_sections_panel',
	)
);

// Add about section enable setting and control.
$wp_customize->add_setting( 'philosophy_pro_theme_options[about_enable]', 
	array(
		'default'           => $options['about_enable'],
		'sanitize_callback' => 'philosophy_pro_sanitize_select',
	)
);

$wp_customize->add_control( 'philosophy_pro_theme_options[about_enable]', 
	array(
		'label'             => esc_html__( 'Enable on', 'philosophy-pro' ),
		'section'           => 'philosophy_pro_about_section',
		'type'              => 'select',
		'choices'           => philosophy_pro_enable_disable_options(),
	)
);

// Add about section content type setting and control.
$wp_customize->add_setting( 'philosophy_pro_theme_options[about_content_type]', array(
		'default'           => $options['about_content_type'],
		'sanitize_callback' => 'philosophy_pro_sanitize_select',
	)
);

$wp_customize->add_control( 'philosophy_pro_theme_options[about_content_type]', array(
		'label'           	=> esc_html__( 'Content Type', 'philosophy-pro' ),
		'section'         	=> 'philosophy_pro_about_section',
		'type'            	=> 'select',
		'active_callback' 	=> 'philosophy_pro_is_about_enable',
		'choices'         	=> array(
			'demo'     		=> esc_html__( 'Demo', 'philosophy-pro' ),
			'posts'    		=> esc_html__( 'Posts', 'philosophy-pro' ),
			'pages'    		=> esc_html__( 'Pages', 'philosophy-pro' ),
			'custom'   		=> esc_html__( 'Custom', 'philosophy-pro' ),
	    ),
	)
);

// Add setting and controls to input post id
$wp_customize->add_setting( 'philosophy_pro_theme_options[about_post_id]', 
	array(
		'sanitize_callback' => 'philosophy_pro_sanitize_number_range',
	)
);

$wp_customize->add_control( 'philosophy_pro_theme_options[about_post_id]', 
	array(
		'label'           	=> esc_html__( 'Enter Post ID', 'philosophy-pro' ),
		'section'         	=> 'philosophy_pro_about_section',
		'input_attrs'     	=> array( 
			'style'       	=> 'width: 100px;',
			'min'         	=> '1', 
			'placeholder' 	=> esc_attr__( 'Post ID', 'philosophy-pro' ),
		),
		'type'        		=> 'number',
		'active_callback' 	=> 'philosophy_pro_is_about_content_post_active',
	)
);

// Add setting and controls to input page id
$wp_customize->add_setting( 'philosophy_pro_theme_options[about_page_id]', 
	array(
		'sanitize_callback' => 'philosophy_pro_sanitize_page',
	)
);

$wp_customize->add_control( 'philosophy_pro_theme_options[about_page_id]', 
	array(
		'label'             => esc_html__( 'Select Page' , 'philosophy-pro' ),
		'section'           => 'philosophy_pro_about_section',
		'active_callback'	=> 'philosophy_pro_is_about_content_page_active',
		'type'              => 'dropdown-pages',
	)
);

// Add about section custom title
$wp_customize->add_setting( 'philosophy_pro_theme_options[about_custom_title]',
	array(
		'sanitize_callback'	=> 'sanitize_text_field',
		'default' 			=> $options['about_custom_title'],
	)
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'philosophy_pro_theme_options[about_custom_title]', array(
		'selector'            => '#about h2.entry-title',
		'render_callback'     => 'philisophy_pro_about_custom_title_refresh',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

$wp_customize->add_control( 'philosophy_pro_theme_options[about_custom_title]',
	array(
		'label'      		=> esc_html__( 'Title', 'philosophy-pro' ),
		'description'		=> esc_html__( 'Enter Title.', 'philosophy-pro' ),
		'section'    		=> 'philosophy_pro_about_section',
	    'active_callback'	=> 'philosophy_pro_is_about_content_custom_active',
	)
);

// Add about section sub title
$wp_customize->add_setting( 'philosophy_pro_theme_options[about_subtitle]', 
	array(
		'sanitize_callback'	=> 'sanitize_text_field',
		'default' 			=> $options['about_subtitle'],
		'transport' 		=> 'postMessage',
	)
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'philosophy_pro_theme_options[about_subtitle]', array(
		'selector'            => '#about h3.sub-title',
		'render_callback'     => 'philisophy_pro_about_subtitle_refresh',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

$wp_customize->add_control( 'philosophy_pro_theme_options[about_subtitle]', 
	array(
		'label'      		=> esc_html__( 'Subtitle', 'philosophy-pro' ),
		'description'		=> esc_html__( 'Enter subtitle.', 'philosophy-pro' ),
		'section'    		=> 'philosophy_pro_about_section',
	    'active_callback'	=> 'philosophy_pro_is_about_content_demo_inactive',
	)
);

// Add about section custom description
$wp_customize->add_setting( 'philosophy_pro_theme_options[about_custom_description]', 
	array(
		'sanitize_callback'	=> 'esc_textarea',
		'default' 			=> $options['about_custom_description'],
		'transport' 		=> 'postMessage',
	)
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'philosophy_pro_theme_options[about_custom_description]', array(
		'selector'            => '#about .entry-content p',
		'render_callback'     => 'philisophy_pro_about_custom_description_refresh',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

$wp_customize->add_control( 'philosophy_pro_theme_options[about_custom_description]', 
	array(
		'label'           	=> esc_html__( 'Description', 'philosophy-pro' ),
		'description'     	=> esc_html__( 'Input description.', 'philosophy-pro' ),
		'section'         	=> 'philosophy_pro_about_section',
		'type'            	=> 'textarea',
		'active_callback' 	=> 'philosophy_pro_is_about_content_custom_active',
	)
);

// Add learn more text
$wp_customize->add_setting( 'philosophy_pro_theme_options[about_learn_more_text]', array(
		'sanitize_callback'	=> 'sanitize_text_field',
		'default' 			=> $options['about_learn_more_text'],
		'transport' 		=> 'postMessage',
	)
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'philosophy_pro_theme_options[about_learn_more_text]', array(
		'selector'            => '#about a.view-more',
		'render_callback'     => 'philisophy_pro_about_learn_more_text_refresh',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

$wp_customize->add_control( 'philosophy_pro_theme_options[about_learn_more_text]', array(
		'label'      		=> esc_html__( 'Learn More Text', 'philosophy-pro' ),
		'description'		=> esc_html__( 'Enter learn more text. Leave empty to hide button.', 'philosophy-pro' ),
		'section'    		=> 'philosophy_pro_about_section',
	    'active_callback'	=> 'philosophy_pro_is_about_content_demo_inactive',
	)
);

// Add learn more custom link setting and control.
$wp_customize->add_setting( 'philosophy_pro_theme_options[about_custom_link]', 
	array(
		'default'           => $options['about_custom_link'],
		'sanitize_callback' => 'esc_url_raw'
	)
);

$wp_customize->add_control( 'philosophy_pro_theme_options[about_custom_link]', 
	array(
		'label'           	=> esc_html__( 'Link', 'philosophy-pro' ),
		'description'     	=> esc_html__( 'Input link', 'philosophy-pro' ),
		'section'         	=> 'philosophy_pro_about_section',
		'type'            	=> 'url',
		'active_callback' 	=> 'philosophy_pro_is_about_content_custom_active',
	)
);

// Add custom image setting and control.
$wp_customize->add_setting( 'philosophy_pro_theme_options[about_custom_image]', array(
		'default'           => $options['about_custom_image'],
		'sanitize_callback' => 'philosophy_pro_sanitize_image',
	)
);

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'philosophy_pro_theme_options[about_custom_image]',
    array(
		'label'           	=> esc_html__( 'Upload image', 'philosophy-pro' ),
		'description'     	=> esc_html__( 'Recommended slide image size is 450x515 px', 'philosophy-pro' ),
		'section'         	=> 'philosophy_pro_about_section',
		'active_callback' 	=> 'philosophy_pro_is_about_content_custom_active',
   )
) );