<?php
/**
 * Philosophy Pro Clients section customizer options
 *
 * @package Theme_Palace
 * @subpackage Philosophy_Pro
 * @since 1.0
 */

// Add testimonial section
$wp_customize->add_section( 'philosophy_pro_clients_section', array(
	'title'             => esc_html__( 'Clients','philosophy-pro' ),
	'description'       => esc_html__( 'Clients section options.', 'philosophy-pro' ),
	'panel'             => 'philosophy_pro_homepage_sections_panel'
) );

// Add testimonial section enable setting and control.
$wp_customize->add_setting( 'philosophy_pro_theme_options[clients_enable]', array(
	'default'           => $options['clients_enable'],
	'sanitize_callback' => 'philosophy_pro_sanitize_select'
) );

$wp_customize->add_control( 'philosophy_pro_theme_options[clients_enable]', array(
	'label'             => esc_html__( 'Enable on', 'philosophy-pro' ),
	'section'           => 'philosophy_pro_clients_section',
	'type'              => 'select',
	'choices'           => philosophy_pro_enable_disable_options()
) );

/**
 * Title and subtitle options
 */

// Add teams custom title setting and control.
$wp_customize->add_setting( 'philosophy_pro_theme_options[clients_custom_title]', array(
	'default'           => $options['clients_custom_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport' 		=> 'postMessage',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'philosophy_pro_theme_options[clients_custom_title]', array(
		'selector'            => '#testimonial h2.entry-title',
		'render_callback'     => 'philisophy_pro_clients_custom_title_refresh',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

$wp_customize->add_control( 'philosophy_pro_theme_options[clients_custom_title]', array(
	'label'           	=> esc_html__( 'Title', 'philosophy-pro' ),
	'description'		=> esc_html__( 'Input title', 'philosophy-pro' ),
	'section'         	=> 'philosophy_pro_clients_section',
	'active_callback' 	=> 'philosophy_pro_is_clients_demo_inactive',
) );

// Add teams custom subtitle setting and control.
$wp_customize->add_setting( 'philosophy_pro_theme_options[clients_custom_subtitle]', array(
	'default'           => $options['clients_custom_subtitle'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport' 		=> 'postMessage',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'philosophy_pro_theme_options[clients_custom_subtitle]', array(
		'selector'            => '#testimonial h3.sub-title',
		'render_callback'     => 'philisophy_pro_clients_custom_subtitle_refresh',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

$wp_customize->add_control( 'philosophy_pro_theme_options[clients_custom_subtitle]', array(
	'label'           	=> esc_html__( 'Subtitle', 'philosophy-pro' ),
	'description'		=> esc_html__( 'Input subtitle', 'philosophy-pro' ),
	'section'         	=> 'philosophy_pro_clients_section',
	'active_callback' 	=> 'philosophy_pro_is_clients_demo_inactive',
) );

// Add testimonial section content type setting and control.
$wp_customize->add_setting( 'philosophy_pro_theme_options[clients_content_type]', array(
	'default'           => $options['clients_content_type'],
	'sanitize_callback' => 'philosophy_pro_sanitize_select',
) );

$wp_customize->add_control( 'philosophy_pro_theme_options[clients_content_type]', array(
	'label'           	=> esc_html__( 'Content Type', 'philosophy-pro' ),
	'description' 		=> esc_html__( 'Content Type options', 'philosophy-pro' ),
	'section'         	=> 'philosophy_pro_clients_section',
	'type'            	=> 'select',
	'choices'         	=> array(
		'demo'     		=> esc_html__( 'Demo', 'philosophy-pro' ),
		'posts'    		=> esc_html__( 'Posts', 'philosophy-pro' ),
		'page'     		=> esc_html__( 'Page', 'philosophy-pro' ),
		'category' 		=> esc_html__( 'Category', 'philosophy-pro' ),
	),
	'active_callback' 	=> 'philosophy_pro_is_clients_enable',
) );

// Add testimonial section number of posts setting and control.
$wp_customize->add_setting( 'philosophy_pro_theme_options[clients_no_of_slides]', array(
	'default'           => $options['clients_no_of_slides'],
	'sanitize_callback' => 'philosophy_pro_sanitize_number_range'
) );

$wp_customize->add_control( 'philosophy_pro_theme_options[clients_no_of_slides]', array(
	'label'           	=> esc_html__( 'Number Of Clients', 'philosophy-pro' ),
	'description'       => esc_html__( 'Notice: Please refresh after the number of slides is set to see the effects. Min = 4 and Max = 10', 'philosophy-pro' ),
	'section'         	=> 'philosophy_pro_clients_section',
	'type'            	=> 'number',
	'input_attrs'		=> array(
		'min'			=> '4',
		'max'			=> '10',
		'step'			=> '1',
		'style'			=> 'width:50px',
	),
	'active_callback' 	=> 'philosophy_pro_is_clients_demo_inactive',
) );

$clients_no_of_slides = $options['clients_no_of_slides']; 

for ( $i=1; $i <= $clients_no_of_slides; $i++ ) { 

	// Add setting and controls to input page id
	$wp_customize->add_setting( 'philosophy_pro_theme_options[clients_page_id_'. $i .']', array(
		'sanitize_callback' => 'philosophy_pro_sanitize_page'
	) );

	$wp_customize->add_control( 'philosophy_pro_theme_options[clients_page_id_'. $i .']', array(
		'label'           => sprintf( esc_html__( 'Clients Page #%s' , 'philosophy-pro' ), $i ),
		'section'         => 'philosophy_pro_clients_section',
		'type'            => 'dropdown-pages',
		'active_callback' => 'philosophy_pro_is_clients_content_page_active',
	) );
}

// Add setting and controls to input post id
$wp_customize->add_setting( 'philosophy_pro_theme_options[clients_post_ids]', array(
	'sanitize_callback' => 'philosophy_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'philosophy_pro_theme_options[clients_post_ids]', array(
	'label'           	=> esc_html__( 'Clients ID', 'philosophy-pro' ),
	'description'     	=> esc_html__( 'Enter post ID seperated with comma. Example 88,91,93', 'philosophy-pro' ),
	'section'         	=> 'philosophy_pro_clients_section',
	'active_callback' 	=> 'philosophy_pro_is_clients_content_post_active',
) );

// Add Category Content Type
$wp_customize->add_setting(  'philosophy_pro_theme_options[clients_content_category]', array(
  	'sanitize_callback' => 'philosophy_pro_sanitize_muti_select_categories_list',
) ) ;

$wp_customize->add_control( new Philosophy_Pro_Multi_Select_Categories_Control ( $wp_customize,'philosophy_pro_theme_options[clients_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'philosophy-pro' ),
	'section'           => 'philosophy_pro_clients_section',
	'active_callback'   => 'philosophy_pro_is_clients_category_active'
) ) );

