<?php
/**
 * Contact Customizer options
 *
 * @package Theme_Palace
 * @subpackage Philosophy_Pro
 * @since Philosophy Pro 1.0
 */

// Add contact enable section
$wp_customize->add_section( 'philosophy_pro_contact_section', array(
	'title'             => esc_html__( 'Contact','philosophy-pro' ),
	'description'       => esc_html__( 'Contact section options.', 'philosophy-pro' ),
	'panel'             => 'philosophy_pro_homepage_sections_panel'
) );

// Add contact enable setting and control.
$wp_customize->add_setting( 'philosophy_pro_theme_options[contact_enable]', array(
	'default'           => $options['contact_enable'],
	'sanitize_callback' => 'philosophy_pro_sanitize_select'
) );

$wp_customize->add_control( 'philosophy_pro_theme_options[contact_enable]', array(
	'label'             => esc_html__( 'Enable on', 'philosophy-pro' ),
	'section'           => 'philosophy_pro_contact_section',
	'type'              => 'select',
	'choices'           => philosophy_pro_enable_disable_options()
) );

// Add contact content type setting and control.
$wp_customize->add_setting( 'philosophy_pro_theme_options[contact_content_type]', array(
	'default'           => $options['contact_content_type'],
	'sanitize_callback' => 'philosophy_pro_sanitize_select'
) );

$wp_customize->add_control( 'philosophy_pro_theme_options[contact_content_type]', array(
	'label'           	=> esc_html__( 'Content Type', 'philosophy-pro' ),
	'section'         	=> 'philosophy_pro_contact_section',
	'type'            	=> 'select',
	'active_callback' 	=> 'philosophy_pro_is_contact_active',
	'choices'         	=> array(
		'demo'   		=> esc_html__( 'Demo', 'philosophy-pro' ),
		'custom' 		=> esc_html__( 'Custom Content', 'philosophy-pro' )
	)
) );

// Add contact section custom title
$wp_customize->add_setting( 'philosophy_pro_theme_options[contact_custom_title]',array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default' 			=> $options['contact_custom_title'],
	'transport' 		=> 'postMessage',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'philosophy_pro_theme_options[contact_custom_title]', array(
		'selector'            => '#contact h2.entry-title',
		'render_callback'     => 'philisophy_pro_contact_custom_title_refresh',
		'container_inclusive' =>  false,
		'fallback_refresh'    =>  true,
	) );
}

$wp_customize->add_control( 'philosophy_pro_theme_options[contact_custom_title]',array(
	'label'      		=> esc_html__( 'Title', 'philosophy-pro' ),
	'description'		=> esc_html__( 'Enter Title.', 'philosophy-pro' ),
	'section'    		=> 'philosophy_pro_contact_section',
    'active_callback'	=> 'philosophy_pro_is_contact_content_demo_inactive',
) );

// Add contact section sub title
$wp_customize->add_setting( 'philosophy_pro_theme_options[contact_subtitle]',array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default' 			=> $options['contact_subtitle'],
	'transport' 		=> 'postMessage',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'philosophy_pro_theme_options[contact_subtitle]', array(
		'selector'            => '#contact h3.sub-title',
		'render_callback'     => 'philisophy_pro_contact_subtitle_refresh',
		'container_inclusive' =>  false,
		'fallback_refresh'    =>  true,
	) );
}

$wp_customize->add_control( 'philosophy_pro_theme_options[contact_subtitle]',array(
	'label'      		=> esc_html__( 'Subtitle', 'philosophy-pro' ),
	'description'		=> esc_html__( 'Enter subtitle.', 'philosophy-pro' ),
	'section'    		=> 'philosophy_pro_contact_section',
    'active_callback'	=> 'philosophy_pro_is_contact_content_demo_inactive',
) );

/**
 * Contact options
 */

// Add contact control options heading setting and control.
$wp_customize->add_setting( 'philosophy_pro_theme_options[contact_options_heading]', array(
	'sanitize_callback' => 'esc_textarea'
) );

$wp_customize->add_control( new Philosophy_Pro_Note_Control( $wp_customize, 'philosophy_pro_theme_options[contact_options_heading]', array(
	'label'           	=> esc_html__( 'Contact Options', 'philosophy-pro' ),
	'description' 		=> esc_html__( 'Contact section options', 'philosophy-pro' ),
	'section'         	=> 'philosophy_pro_contact_section',
	'type'				=> 'description',
	'active_callback' 	=> 'philosophy_pro_is_contact_content_demo_inactive',
) ) );

// Add contact fax icon setting and control.
$wp_customize->add_setting( 'philosophy_pro_theme_options[contact_address_label]', array(
	'default'           => $options['contact_address_label'],
	'sanitize_callback' => 'sanitize_text_field'
) );
$wp_customize->add_control( 'philosophy_pro_theme_options[contact_address_label]', array(
	'label'             => esc_html__( 'Address Label', 'philosophy-pro' ),
	'section'           => 'philosophy_pro_contact_section',
	'active_callback' 	=> 'philosophy_pro_is_contact_content_demo_inactive',
) );

// Add contact address setting and control.
$wp_customize->add_setting( 'philosophy_pro_theme_options[contact_address]', array(
	'default'           => $options['contact_address'],
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'philosophy_pro_theme_options[contact_address]', array(
	'label'             => esc_html__( 'Address', 'philosophy-pro' ),
	'description'       => esc_html__( 'Enter address', 'philosophy-pro' ),
	'section'           => 'philosophy_pro_contact_section',
	'active_callback' 	=> 'philosophy_pro_is_contact_content_demo_inactive',
) );

// Add contact phone icon setting and control.
$wp_customize->add_setting( 'philosophy_pro_theme_options[contact_phone_label]', array(
	'default'           => $options['contact_phone_label'],
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'philosophy_pro_theme_options[contact_phone_label]', array(
	'label'             => esc_html__( 'Phone Label', 'philosophy-pro' ),
	'section'           => 'philosophy_pro_contact_section',
	'active_callback' 	=> 'philosophy_pro_is_contact_content_demo_inactive',
) );

// Add contact phone number setting and control
$wp_customize->add_setting( 'philosophy_pro_theme_options[contact_phone_number]', array(
	'default'			=> $options['contact_phone_number'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'philosophy_pro_theme_options[contact_phone_number]', array(
	'label'           	=> esc_html__( 'Phone Number', 'philosophy-pro' ),
	'description'		=> esc_html__( 'Enter phone number', 'philosophy-pro' ),
	'section'         	=> 'philosophy_pro_contact_section',
	'active_callback' 	=> 'philosophy_pro_is_contact_content_demo_inactive',
	'type'				=> 'text'
) );

// Add contact fax icon setting and control.
$wp_customize->add_setting( 'philosophy_pro_theme_options[contact_email_label]', array(
	'default'           => $options['contact_email_label'],
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'philosophy_pro_theme_options[contact_email_label]', array(
	'label'             => esc_html__( 'Email Label', 'philosophy-pro' ),
	'section'           => 'philosophy_pro_contact_section',
	'input_attrs'		=> array( 
		'placeholder' 	=> esc_attr( 'fa-envelope', 'philosophy-pro' ),
	),
	'active_callback' 	=> 'philosophy_pro_is_contact_content_demo_inactive',
) );

// Add Email setting and control
$wp_customize->add_setting( 'philosophy_pro_theme_options[contact_email]', array(
	'default'			=> $options['contact_email'],
	'sanitize_callback' => 'sanitize_email',
) );

$wp_customize->add_control( 'philosophy_pro_theme_options[contact_email]', array(
	'label'           	=> esc_html__( 'Contact Email', 'philosophy-pro' ),
	'description'		=> esc_html__( 'Enter email', 'philosophy-pro' ),
	'section'         	=> 'philosophy_pro_contact_section',
	'active_callback' 	=> 'philosophy_pro_is_contact_content_demo_inactive',
	'type'				=> 'email'
) );

/**
 * Custom background option
 */

// Add contact background image setting and control.
$wp_customize->add_setting( 'philosophy_pro_theme_options[contact_background_image]', array(
	'default'           => $options['contact_background_image'],
	'sanitize_callback' => 'philosophy_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'philosophy_pro_theme_options[contact_background_image]',
    array(
		'label'           => esc_html__( 'Upload a background image', 'philosophy-pro' ),
		'description'     => esc_html__( 'Recommended background image size is 1920x420 px', 'philosophy-pro' ),
		'section'         => 'philosophy_pro_contact_section',
		'active_callback' => 'philosophy_pro_is_contact_content_demo_inactive',
   	)
) );


// Add contact form options heading setting and control.
$wp_customize->add_setting( 'philosophy_pro_theme_options[contact_form_heading]', array(
	'sanitize_callback' => 'esc_textarea'
) );

$wp_customize->add_control( new Philosophy_Pro_Note_Control( $wp_customize, 'philosophy_pro_theme_options[contact_form_heading]', array(
	'label'           	=> esc_html__( 'Contact Form Options', 'philosophy-pro' ),
	'section'         	=> 'philosophy_pro_contact_section',
	'type'				=> 'description',
	'active_callback' 	=> 'philosophy_pro_is_contact_content_demo_inactive',
) ) );


/**
 * Check if Contact Form 7 plugin is active.
 */

if ( ! class_exists( 'WPCF7' ) ) {
	$contact_form_description = sprintf( '<a href="https://wordpress.org/plugins/contact-form-7/">%1$s</a> %2$s', esc_html__( 'Contact Form 7', 'philosophy-pro' ), esc_html__( 'plugin is recommended for contact forms. After installing CF7 Plugin Input shortcode here.', 'philosophy-pro' ) );
} else {
	$contact_form_description = esc_html__( 'Input contact form shortcode.', 'philosophy-pro' );
}


// Show contact form shortcode setting and control
$wp_customize->add_setting( 'philosophy_pro_theme_options[contact_form_shortcode]', array(
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'philosophy_pro_theme_options[contact_form_shortcode]', array(
	'label'           	=> esc_html__( 'Contact Form Shortcode', 'philosophy-pro' ),
	'description'     	=> $contact_form_description,
	'section'         	=> 'philosophy_pro_contact_section',
	'active_callback' 	=> 'philosophy_pro_is_contact_content_demo_inactive',
	'type'            	=> 'textarea',
) );

// Add  enable  social links setting and control.
$wp_customize->add_setting( 'philosophy_pro_theme_options[enable_social_links]', array(
	'default'           => $options['enable_social_links'],
	'sanitize_callback' => 'philosophy_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'philosophy_pro_theme_options[enable_social_links]', array(
	'label'             => esc_html__( 'Enable Social Links.', 'philosophy-pro' ),
	'section'           => 'philosophy_pro_contact_section',
	'type'              => 'checkbox',
	'active_callback' 	=> 'philosophy_pro_is_contact_content_demo_inactive'
) );


// Add no of social link setting and control
$wp_customize->add_setting( 'philosophy_pro_theme_options[no_of_social_link]', array(
	'default'			=> $options['no_of_social_link'],
	'sanitize_callback' => 'philosophy_pro_sanitize_number_range',
) );

$wp_customize->add_control( 'philosophy_pro_theme_options[no_of_social_link]', array(
	'label'           	=> esc_html__( 'Number of Social Links', 'philosophy-pro' ),
	'description'		=> esc_html__( 'Enter number of social links. Save and then refresh page to view changes. Min 2 and Max 5', 'philosophy-pro' ),
	'section'         	=> 'philosophy_pro_contact_section',
	'active_callback' 	=> 'philosophy_pro_is_contact_social_link_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'			=> 2,
		'max'			=> 5,
		'step'			=> 1
	)
) );

$no_of_social_link = $options['no_of_social_link']; // get no of social link

for( $i=1; $i<= $no_of_social_link; $i++ ){
	// Add  enable social links block setting and control.
	$wp_customize->add_setting( 'philosophy_pro_theme_options[social_link_'. $i .']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'philosophy_pro_theme_options[social_link_'. $i .']', array(
		'label'           => sprintf( esc_html__( 'Social Link #%s', 'philosophy-pro' ), $i ),
		'section'         => 'philosophy_pro_contact_section',
		'type'            => 'url',
		'active_callback' => 'philosophy_pro_is_contact_social_link_enable',
	) );
}