<?php
/**
 * Counter Customizer options
 *
 * @package Theme_Palace
 * @subpackage Philosophy_Pro
 * @since Philosophy Pro 1.0
 */


// Add counter enable section
$wp_customize->add_section( 'philosophy_pro_counter_section', array(
	'title'             => esc_html__( 'Counter','philosophy-pro' ),
	'description'       => esc_html__( 'Counter section options.', 'philosophy-pro' ),
	'panel'             => 'philosophy_pro_homepage_sections_panel'
) );

// Add counter enable setting and control.
$wp_customize->add_setting( 'philosophy_pro_theme_options[counter_enable]', array(
	'default'           => $options['counter_enable'],
	'sanitize_callback' => 'philosophy_pro_sanitize_select'
) );

$wp_customize->add_control( 'philosophy_pro_theme_options[counter_enable]', array(
	'label'             => esc_html__( 'Enable on', 'philosophy-pro' ),
	'section'           => 'philosophy_pro_counter_section',
	'type'              => 'select',
	'choices'           => philosophy_pro_enable_disable_options()
) );

// Add counter content type setting and control.
$wp_customize->add_setting( 'philosophy_pro_theme_options[counter_content_type]', array(
	'default'           => $options['counter_content_type'],
	'sanitize_callback' => 'philosophy_pro_sanitize_select'
) );

$wp_customize->add_control( 'philosophy_pro_theme_options[counter_content_type]', array(
	'label'           	=> esc_html__( 'Content Type', 'philosophy-pro' ),
	'section'         	=> 'philosophy_pro_counter_section',
	'type'            	=> 'select',
	'active_callback' 	=> 'philosophy_pro_is_counter_active',
	'choices'         	=> array(
		'demo'   	  	=> esc_html__( 'Demo', 'philosophy-pro' ),
		'custom' 	  	=> esc_html__( 'Custom Content', 'philosophy-pro' )
	)
) );

// Add counter layout setting and control.
$wp_customize->add_setting( 'philosophy_pro_theme_options[counter_section_layout]', array(
	'default'           => $options['counter_section_layout'],
	'sanitize_callback' => 'philosophy_pro_sanitize_select'
) );

$wp_customize->add_control( 'philosophy_pro_theme_options[counter_section_layout]', array(
	'label'           	=> esc_html__( 'Select Layout', 'philosophy-pro' ),
	'section'         	=> 'philosophy_pro_counter_section',
	'type'            	=> 'select',
	'active_callback' 	=> 'philosophy_pro_is_counter_active',
	'choices'         	=> array(
		'three-columns'	=> esc_html__( 'Three Columns', 'philosophy-pro'),
		'four-columns'	=> esc_html__( 'Four Columns','philosophy-pro'),
	)
) );

/**
 * Counter options
 */

// Add counter control options heading setting and control.
$wp_customize->add_setting( 'philosophy_pro_theme_options[counter_options_heading]', array(
	'sanitize_callback' => 'esc_textarea'
) );

$wp_customize->add_control( new Philosophy_Pro_Note_Control( $wp_customize, 'philosophy_pro_theme_options[counter_options_heading]', array(
	'label'           	=> esc_html__( 'Counter Options', 'philosophy-pro' ),
	'section'         	=> 'philosophy_pro_counter_section',
	'type'				=> 'description',
	'active_callback' 	=> 'philosophy_pro_is_counter_content_demo_inactive',
) ) );

$no_of_counter = ( 'three-columns' == $options['counter_section_layout'] ) ? 3 : 4; 

for ( $i=1; $i<=$no_of_counter; $i++ ) {
	// Show counter icon setting and control
	$wp_customize->add_setting( 'philosophy_pro_theme_options[counter_icon_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( 'philosophy_pro_theme_options[counter_icon_'.$i.']', array(
		'description'     	=> sprintf( '%1$s <a target="_blank" href="%2$s">%3$s</a>', esc_html__( 'Example fa-cloud-upload see more at', 'philosophy-pro' ), esc_url( 'http://fontawesome.io/icons/' ), esc_html__( 'Font awesome', 'philosophy-pro' ) ),
		'section'         	=> 'philosophy_pro_counter_section',
		'active_callback' 	=> 'philosophy_pro_is_counter_content_demo_inactive',
		'input_attrs'     	=> array( 
			'placeholder' 	=> esc_attr__( 'fa-user', 'philosophy-pro' ) 
		)
	) );

	// Show counter name setting and control
	$wp_customize->add_setting( 'philosophy_pro_theme_options[counter_name_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( 'philosophy_pro_theme_options[counter_name_'.$i.']', array(
		'label'           	=> sprintf( esc_html__( 'Name %1$s', 'philosophy-pro' ), $i ),
		'section'         	=> 'philosophy_pro_counter_section',
		'active_callback' 	=> 'philosophy_pro_is_counter_content_demo_inactive',
	) );

	// Show counter count setting and control
	$wp_customize->add_setting( 'philosophy_pro_theme_options[counter_count_'.$i.']', array(
		'sanitize_callback' => 'philosophy_pro_sanitize_number_range'
	) );

	$wp_customize->add_control( 'philosophy_pro_theme_options[counter_count_'.$i.']', array(
		'label'           	=> sprintf( esc_html__( 'Count %1$s', 'philosophy-pro' ), $i ),
		'section'         	=> 'philosophy_pro_counter_section',
		'active_callback' 	=> 'philosophy_pro_is_counter_content_demo_inactive',
		'type'			  	=> 'number',
		'input_attrs'	  	=> array(
			'min' 		  	=> 0
		)
	) );

	// Counter hr setting and control
	$wp_customize->add_setting( 'philosophy_pro_theme_options[counter_content_custom_hr_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new philosophy_pro_Customize_Horizontal_Line( $wp_customize, 'philosophy_pro_theme_options[counter_content_custom_hr_'.$i.']',
		array(
			'section'         => 'philosophy_pro_counter_section',
			'active_callback' => 'philosophy_pro_is_counter_content_demo_inactive',
			'type'			  => 'hr'
	) ) );
}

// Add background image setting and control.
$wp_customize->add_setting( 'philosophy_pro_theme_options[counter_background_image]', array(
	'default'           	=> $options['counter_background_image'],
	'sanitize_callback' 	=> 'esc_url_raw'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'philosophy_pro_theme_options[counter_background_image]',
    array(
		'label'           	=> esc_html__( 'Upload a background image', 'philosophy-pro' ),
		'description'     	=> esc_html__( 'Recommended background image size is 1920x420 px', 'philosophy-pro' ),
		'section'         	=> 'philosophy_pro_counter_section',
		'active_callback' 	=> 'philosophy_pro_is_counter_content_demo_inactive',
   	)
) );
