<?php
/**
 * Philosophy Pro skills section customizer options
 *
 * @package Theme_Palace
 * @subpackage Philosophy_Pro
 * @since 1.0
 */

// Add skills section
$wp_customize->add_section( 'philosophy_pro_skills_section', array(
	'title'             => esc_html__( 'Skills', 'philosophy-pro' ),
	'description'       => esc_html__( 'Skills section options.', 'philosophy-pro' ),
	'panel'             => 'philosophy_pro_homepage_sections_panel'
) );

// Add skills section enable setting and control.
$wp_customize->add_setting( 'philosophy_pro_theme_options[skills_enable]', array(
	'default'           => $options['skills_enable'],
	'sanitize_callback' => 'philosophy_pro_sanitize_select'
) );

$wp_customize->add_control( 'philosophy_pro_theme_options[skills_enable]', array(
	'label'             => esc_html__( 'Enable on', 'philosophy-pro' ),
	'section'           => 'philosophy_pro_skills_section',
	'type'              => 'select',
	'choices'           => philosophy_pro_enable_disable_options()
) );

// Add skills section content type setting and control.
$wp_customize->add_setting( 'philosophy_pro_theme_options[skills_content_type]', array(
	'default'           => $options['skills_content_type'],
	'sanitize_callback' => 'philosophy_pro_sanitize_select'
) );

$wp_customize->add_control( 'philosophy_pro_theme_options[skills_content_type]', array(
	'label'           	=> esc_html__( 'Content Type', 'philosophy-pro' ),
	'section'         	=> 'philosophy_pro_skills_section',
	'type'            	=> 'select',
	'active_callback' 	=> 'philosophy_pro_is_skills_enable',
	'choices'         	=> array(
		'demo'     		=> esc_html__( 'Demo', 'philosophy-pro' ),
		'posts'    		=> esc_html__( 'Posts', 'philosophy-pro' ),
		'pages'    		=> esc_html__( 'Pages', 'philosophy-pro' ),
		'custom'   		=> esc_html__( 'Custom', 'philosophy-pro' ),
    ),
) );

// Add setting and controls to input post id
$wp_customize->add_setting( 'philosophy_pro_theme_options[skills_post_id]', array(
	'sanitize_callback' => 'philosophy_pro_sanitize_number_range',
) );

$wp_customize->add_control( 'philosophy_pro_theme_options[skills_post_id]', array(
	'label'           	=> esc_html__( 'Enter Post ID', 'philosophy-pro' ),
	'section'         	=> 'philosophy_pro_skills_section',
	'input_attrs' 		=> array( 
		'style' 		=> 'width: 100px;',
		'min'			=> '1', 
		'placeholder'	=> esc_attr__( 'Post ID', 'philosophy-pro' ) ),
	'type'              => 'number',
	'active_callback' 	=> 'philosophy_pro_is_skills_content_post_active',
) );

// Add setting and controls to input page id
$wp_customize->add_setting( 'philosophy_pro_theme_options[skills_page_id]', array(
	'sanitize_callback' => 'philosophy_pro_sanitize_page'
) );

$wp_customize->add_control( 'philosophy_pro_theme_options[skills_page_id]', array(
	'label'             => esc_html__( 'Select Page' , 'philosophy-pro' ),
	'section'           => 'philosophy_pro_skills_section',
	'active_callback'	=> 'philosophy_pro_is_skills_content_page_active',
	'type'              => 'dropdown-pages',
) );

// Add skills section custom title
$wp_customize->add_setting( 'philosophy_pro_theme_options[skills_custom_title]',array(
	'sanitize_callback'		=> 'sanitize_text_field',
	'default' 				=> $options['skills_custom_title'],
	'transport' 			=> 'postMessage',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'philosophy_pro_theme_options[skills_custom_title]', array(
		'selector'            => '#skill h2.entry-title',
		'render_callback'     => 'philisophy_pro_skills_custom_title_refresh',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

$wp_customize->add_control( 'philosophy_pro_theme_options[skills_custom_title]',array(
	'label'      			=> esc_html__( 'Title', 'philosophy-pro' ),
	'description'			=> esc_html__( 'Enter Title.', 'philosophy-pro' ),
	'section'    			=> 'philosophy_pro_skills_section',
    'active_callback'		=> 'philosophy_pro_is_skills_content_custom_active',
) );

// Add skills section sub title
$wp_customize->add_setting( 'philosophy_pro_theme_options[skills_subtitle]',array(
	'sanitize_callback'		=> 'sanitize_text_field',
	'default' 				=> $options['skills_subtitle'],
	'transport' 			=> 'postMessage',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'philosophy_pro_theme_options[skills_subtitle]', array(
		'selector'            => '#skill h3.sub-title',
		'render_callback'     => 'philisophy_pro_skills_subtitle_refresh',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

$wp_customize->add_control( 'philosophy_pro_theme_options[skills_subtitle]',array(
	'label'      			=> esc_html__( 'Subtitle', 'philosophy-pro' ),
	'description'			=> esc_html__( 'Enter subtitle.', 'philosophy-pro' ),
	'section'    			=> 'philosophy_pro_skills_section',
    'active_callback'		=> 'philosophy_pro_is_skills_content_demo_inactive',
) );

// Add skills section custom description
$wp_customize->add_setting( 'philosophy_pro_theme_options[skills_custom_description]',
	array(
		'sanitize_callback'	=> 'esc_textarea',
		'default' 			=> $options['skills_custom_description'],
		'transport' 		=> 'postMessage',
	)
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'philosophy_pro_theme_options[skills_custom_description]', array(
		'selector'            => '#skill .entry-content p',
		'render_callback'     => 'philisophy_pro_skills_custom_description_refresh',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

$wp_customize->add_control( 'philosophy_pro_theme_options[skills_custom_description]',
    array(
		'label'           	=> esc_html__( 'Description', 'philosophy-pro' ),
		'description'     	=> esc_html__( 'Input description.', 'philosophy-pro' ),
		'section'         	=> 'philosophy_pro_skills_section',
		'type'            	=> 'textarea',
		'active_callback' 	=> 'philosophy_pro_is_skills_content_custom_active',
    )
);

// Add background image setting and control.
$wp_customize->add_setting( 'philosophy_pro_theme_options[skills_custom_image]', array(
	'default'           	=> $options['skills_custom_image'],
	'sanitize_callback' 	=> 'philosophy_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'philosophy_pro_theme_options[skills_custom_image]',
    array(
		'label'           	=> esc_html__( 'Upload Background Image', 'philosophy-pro' ),
		'description'     	=> esc_html__( 'Recommended background image size is 1945x1300 px', 'philosophy-pro' ),
		'section'         	=> 'philosophy_pro_skills_section',
		'active_callback' 	=> 'philosophy_pro_is_skills_content_custom_active',
    )
) );

/**
 * Graph options
 */

// Add graph options setting and control.
$wp_customize->add_setting( 'philosophy_pro_theme_options[skills_graph_heading]', array(
		'sanitize_callback' => 'esc_textarea'
	)
);

$wp_customize->add_control( new Philosophy_Pro_Note_Control( $wp_customize, 'philosophy_pro_theme_options[skills_graph_heading]', 
	array(
		'label'           	=> esc_html__( 'Graph Options', 'philosophy-pro' ),
		'section'         	=> 'philosophy_pro_skills_section',
		'type'				=> 'description',
		'active_callback' 	=> 'philosophy_pro_is_skills_content_demo_inactive',
	)
) );

// Add tp piebuilder shortcode setting and control
$wp_customize->add_setting( 'philosophy_pro_theme_options[skills_graph_shortcode]', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'           => $options['skills_graph_shortcode'],
) );

$wp_customize->add_control( 'philosophy_pro_theme_options[skills_graph_shortcode]', array(
		'label'           => esc_html__( 'Graph Shortcode', 'philosophy-pro' ),
		'description'     => esc_html__( 'Input graph shortcode.', 'philosophy-pro' ),
		'section'         => 'philosophy_pro_skills_section',
		'active_callback' => 'philosophy_pro_is_skills_content_demo_inactive',
		'type'            => 'textarea',
	)
);