<?php
/**
 * Philosophy Pro slider customizer options
 *
 * @package Theme_Palace
 * @subpackage Philosophy_Pro
 * @since 1.0
 */

// Add slider section
$wp_customize->add_section( 'philosophy_pro_slider_section', 
	array(
		'title'             => esc_html__( 'Slider','philosophy-pro' ),
		'description'       => esc_html__( 'Slider section options.', 'philosophy-pro' ),
		'panel'             => 'philosophy_pro_homepage_sections_panel',
	)
);

// Add slider section enable setting and control.
$wp_customize->add_setting( 'philosophy_pro_theme_options[slider_enable]', 
	array(
		'default'           => $options['slider_enable'],
		'sanitize_callback' => 'philosophy_pro_sanitize_select',
	)
);

$wp_customize->add_control( 'philosophy_pro_theme_options[slider_enable]', 
	array(
		'label'             => esc_html__( 'Enable on', 'philosophy-pro' ),
		'section'           => 'philosophy_pro_slider_section',
		'type'              => 'select',
		'choices'           => philosophy_pro_enable_disable_options(),
	)
);

/**
 * Slider Control options  
 */

// Add slider control options heading setting and control.
$wp_customize->add_setting( 'philosophy_pro_theme_options[slider_control_options_heading]', 
	array(
		'sanitize_callback' => 'esc_textarea',
	)
);

$wp_customize->add_control( new Philosophy_Pro_Note_Control( $wp_customize, 'philosophy_pro_theme_options[slider_control_options_heading]', 
	array(
		'label'           	=> esc_html__( 'Slider Control Options', 'philosophy-pro' ),
		'section'         	=> 'philosophy_pro_slider_section',
		'type'				=> 'description',
		'active_callback' 	=> 'philosophy_pro_is_slider_enable',
	)
 ) );

// Add slider effects setting and controls
$wp_customize->add_setting( 'philosophy_pro_theme_options[slider_content_effect]', array(
		'default'           => $options['slider_content_effect'],
		'sanitize_callback' => 'philosophy_pro_sanitize_select',
	)
);

$wp_customize->add_control( 'philosophy_pro_theme_options[slider_content_effect]', array(
		'label'           	=> esc_html__( 'Transition Effects', 'philosophy-pro' ),
		'section'         	=> 'philosophy_pro_slider_section',
		'type'            	=> 'select',
		'active_callback' 	=> 'philosophy_pro_is_slider_enable',
		'choices'         	=> philosophy_pro_slider_effect(),
	)
);

// Add enable slider controls setting and control.
$wp_customize->add_setting( 'philosophy_pro_theme_options[enable_slider_controls]', array(
		'default'           => $options['enable_slider_controls'],
		'sanitize_callback' => 'philosophy_pro_sanitize_checkbox',
	)
);

$wp_customize->add_control( 'philosophy_pro_theme_options[enable_slider_controls]', array(
		'label'           	=> esc_html__( 'Enable Arrow Controls', 'philosophy-pro' ),
		'section'         	=> 'philosophy_pro_slider_section',
		'type'            	=> 'checkbox',
		'active_callback' 	=> 'philosophy_pro_is_slider_enable',
	)
);

// Add enable slider dragable setting and control.
$wp_customize->add_setting( 'philosophy_pro_theme_options[enable_slider_dragable]', array(
		'default'           => $options['enable_slider_dragable'],
		'sanitize_callback' => 'philosophy_pro_sanitize_checkbox',
	)
);

$wp_customize->add_control( 'philosophy_pro_theme_options[enable_slider_dragable]', array(
		'label'           	=> esc_html__( 'Slider Dragable', 'philosophy-pro' ),
		'section'         	=> 'philosophy_pro_slider_section',
		'type'            	=> 'checkbox',
		'active_callback' 	=> 'philosophy_pro_is_slider_enable',
	)
);

// Add enable slider pause on hover setting and control.
$wp_customize->add_setting( 'philosophy_pro_theme_options[slider_pause_on_hover]', array(
		'default'           => $options['slider_pause_on_hover'],
		'sanitize_callback' => 'philosophy_pro_sanitize_checkbox',
	)
);

$wp_customize->add_control( 'philosophy_pro_theme_options[slider_pause_on_hover]', array(
		'label'           	=> esc_html__( 'Pause On Hover', 'philosophy-pro' ),
		'section'         	=> 'philosophy_pro_slider_section',
		'type'            	=> 'checkbox',
		'active_callback' 	=> 'philosophy_pro_is_slider_enable',
	)
);

// Add enable slider pager option setting and control.
$wp_customize->add_setting( 'philosophy_pro_theme_options[enable_slider_pager]', array(
		'default'           => $options['enable_slider_pager'],
		'sanitize_callback' => 'philosophy_pro_sanitize_checkbox',
	)
);

$wp_customize->add_control( 'philosophy_pro_theme_options[enable_slider_pager]', array(
		'label'           	=> esc_html__( 'Enable Pager', 'philosophy-pro' ),
		'section'         	=> 'philosophy_pro_slider_section',
		'type'            	=> 'checkbox',
		'active_callback' 	=> 'philosophy_pro_is_slider_enable',
	)
);

// Add enable box layout and control.
$wp_customize->add_setting( 'philosophy_pro_theme_options[slider_box_layout]',
	array(
		'default'           => $options['slider_box_layout'],
		'sanitize_callback' => 'philosophy_pro_sanitize_checkbox',
	)
);

$wp_customize->add_control( 'philosophy_pro_theme_options[slider_box_layout]',
	array(
		'label'           	=> esc_html__( 'Enable box layout', 'philosophy-pro' ),
		'section'         	=> 'philosophy_pro_slider_section',
		'type'            	=> 'checkbox',
		'active_callback' 	=> 'philosophy_pro_is_slider_enable',
	)
);

// Add enable box layout and control.
$wp_customize->add_setting( 'philosophy_pro_theme_options[enable_slider_content]', array(
		'default'           => $options['enable_slider_content'],
		'sanitize_callback' => 'philosophy_pro_sanitize_checkbox',
	)
);

$wp_customize->add_control( 'philosophy_pro_theme_options[enable_slider_content]', array(
		'label'           	=> esc_html__( 'Enable slider content', 'philosophy-pro' ),
		'section'         	=> 'philosophy_pro_slider_section',
		'type'            	=> 'checkbox',
		'active_callback' 	=> 'philosophy_pro_is_slider_enable',
	)
);

/**
 * Slider content Option
 */

// Add slider section content type setting and control.
$wp_customize->add_setting( 'philosophy_pro_theme_options[slider_content_type]', array(
		'default'           => $options['slider_content_type'],
		'sanitize_callback' => 'philosophy_pro_sanitize_select',
) );

$wp_customize->add_control( 'philosophy_pro_theme_options[slider_content_type]', array(
		'label'           	=> esc_html__( 'Content Type', 'philosophy-pro' ),
		'section'         	=> 'philosophy_pro_slider_section',
		'type'            	=> 'select',
		'active_callback' 	=> 'philosophy_pro_is_slider_enable',
		'choices'         	=> array(
			'demo'     		=> esc_html__( 'Demo', 'philosophy-pro' ),
			'posts'    		=> esc_html__( 'Posts', 'philosophy-pro' ),
			'pages'    		=> esc_html__( 'Pages', 'philosophy-pro' ),
			'category' 		=> esc_html__( 'Category', 'philosophy-pro' ),
			'custom'   		=> esc_html__( 'Custom', 'philosophy-pro' ),
		),
	)
);

// Add slider section number of posts setting and control.
$wp_customize->add_setting( 'philosophy_pro_theme_options[slider_no_of_slides]', array(
		'default'           => $options['slider_no_of_slides'],
		'sanitize_callback' => 'philosophy_pro_sanitize_number_range',
) );

$wp_customize->add_control( 'philosophy_pro_theme_options[slider_no_of_slides]', array(
		'label'           	=> esc_html__( 'Number Of Slides', 'philosophy-pro' ),
		'description'       => esc_html__( 'Notice: Please refresh after the number of slides is set to see the effects.', 'philosophy-pro' ),
		'section'         	=> 'philosophy_pro_slider_section',
		'type'            	=> 'number',
		'input_attrs'		=> array(
			'min'			=> '2',
			'max'			=> '5',
			'step'			=> '1',
			'style'			=> 'width:50px',
		),
		'active_callback' 	=> 'philosophy_pro_is_slider_demo_not_active',
	)
);

$no_of_slides = $options['slider_no_of_slides'];

for( $i=1; $i<=$no_of_slides; $i++ ){

	// Add setting and controls to input page id
	$wp_customize->add_setting( 'philosophy_pro_theme_options[slider_page_id_' . $i . ']', 
		array(
			'sanitize_callback' => 'philosophy_pro_sanitize_page',
		)
	);

	$wp_customize->add_control( 'philosophy_pro_theme_options[slider_page_id_' . $i . ']', 
		array(
			'label'             => __( 'Select Page # ' , 'philosophy-pro' ) . $i,
			'section'           => 'philosophy_pro_slider_section',
			'active_callback'	=> 'philosophy_pro_slider_content_page_active',
			'type'              => 'dropdown-pages',
		)
	);

	/**
 	 * Content type: Custom
	 */

	// Add slider options setting and control.
	$wp_customize->add_setting( 'philosophy_pro_theme_options[custom_slider_options_'. $i .']', 
		array(
			'sanitize_callback' => 'esc_textarea',
		)
	);

	$wp_customize->add_control( new Philosophy_Pro_Note_Control( $wp_customize, 'philosophy_pro_theme_options[custom_slider_options_'. $i .']', 
		array(
			'label'           	=> sprintf( esc_html__( 'Slide %1$s Options', 'philosophy-pro' ), $i ),
			'section'         	=> 'philosophy_pro_slider_section',
			'type'				=> 'description',
			'active_callback' 	=> 'philosophy_pro_slider_content_custom_active',
		)
	) );

	// Add slider custom title
	$wp_customize->add_setting( 'philosophy_pro_theme_options[custom_slider_title_'. $i .']',
		array(
			'sanitize_callback'	=> 'philosophy_pro_custom_slider_santize_allow_tag',
		)
	);

	$wp_customize->add_control( 'philosophy_pro_theme_options[custom_slider_title_'. $i .']',
	    array(
			'label'           	=> esc_html__( 'Slide Title', 'philosophy-pro' ),
			'description'     	=> sprintf( 'Only Heading Tags &lt;h1&gt; and &lt;h2&gt; are allowded. "Sub-title" class can be used to make subtitle.', 'philosophy-pro' ),
			'section'         	=> 'philosophy_pro_slider_section',
			'type'            	=> 'textarea',
			'input_attrs'     	=> array( 
				'placeholder' 	=> sprintf( '<h1>%1$s</h1><h2>%2$s</h2><h2 class="sub-title">%3$s</h2>', esc_html__( 'Let&rsquo;s Build', 'philosophy-pro' ), esc_html__( 'something great', 'philosophy-pro' ), esc_html__( 'Together', 'philosophy-pro' ) ),
			),
			'active_callback' 	=> 'philosophy_pro_slider_content_custom_active',
	    )
	);

	// Add slide image setting and control.
	$wp_customize->add_setting( 'philosophy_pro_theme_options[custom_slide_image_'. $i .']', 
		array(
			'default'           => $options['slide_ad_image'],
			'sanitize_callback' => 'philosophy_pro_sanitize_image',
		) 
	);

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'philosophy_pro_theme_options[custom_slide_image_'. $i .']',
	    array(
			'label'           	=> esc_html__( 'Upload slide image', 'philosophy-pro' ),
			'description'     	=> esc_html__( 'Recommended slide image size is 1920x1080 px', 'philosophy-pro' ),
			'section'         	=> 'philosophy_pro_slider_section',
			'active_callback' 	=> 'philosophy_pro_slider_content_custom_active',
	    )
	) );

	// Add learn more text setting and control.
	$wp_customize->add_setting( 'philosophy_pro_theme_options[custom_slide_learn_more_text_'. $i .']', 
		array(
			'default'           => $options['custom_slide_learn_more_text'],
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control( 'philosophy_pro_theme_options[custom_slide_learn_more_text_'. $i .']', 
		array(
			'label'           	=> esc_html__( 'Learn More Text', 'philosophy-pro' ),
			'description'     	=> esc_html__( 'Leave empty to hide button', 'philosophy-pro' ),
			'section'         	=> 'philosophy_pro_slider_section',
			'active_callback' 	=> 'philosophy_pro_slider_content_custom_active',
		)
	);

	// Add slider link setting and control.
	$wp_customize->add_setting( 'philosophy_pro_theme_options[custom_slide_link_'. $i .']', 
		array(
			'default'           => $options['custom_slide_link'],
			'sanitize_callback' => 'esc_url_raw',
		)
	);

	$wp_customize->add_control( 'philosophy_pro_theme_options[custom_slide_link_'. $i .']', 
		array(
			'label'           	=> esc_html__( 'Link', 'philosophy-pro' ),
			'description'		=> esc_html__( 'Input link', 'philosophy-pro' ),
			'section'         	=> 'philosophy_pro_slider_section',
			'type'				=> 'url',
			'active_callback' 	=> 'philosophy_pro_slider_content_custom_active',
		) 
	);
	
	// Add horizontol line  setting and control.
	$wp_customize->add_setting( 'philosophy_pro_theme_options[slide_hr_line_'. $i .']', 
		array(
			'sanitize_callback' => 'sanitize_text_field',
		) 
	);

	$wp_customize->add_control( new Philosophy_Pro_Customize_Horizontal_Line( $wp_customize, 'philosophy_pro_theme_options[slide_hr_line_'. $i .']',
	    array(
			'section'         	=> 'philosophy_pro_slider_section',
			'type'			  	=> 'hr',
			'active_callback' 	=> 'philosophy_pro_slider_content_custom_active',
	    )
	) );
}
/**
 * Content type: Post
 */

// Add setting and controls to input post id
$wp_customize->add_setting( 'philosophy_pro_theme_options[slider_posts_ids]', 
	array(
		'sanitize_callback' 	=> 'philosophy_pro_sanitize_post_ids',
	)
);

$wp_customize->add_control( 'philosophy_pro_theme_options[slider_posts_ids]', 
	array(
		'label'           		=> esc_html__( 'Enter Post ID', 'philosophy-pro' ),
		'description' 	  		=> esc_html__( 'Enter post ID seperated with comma. Example 88,91,93', 'philosophy-pro' ),
		'section'         		=> 'philosophy_pro_slider_section',
		'active_callback' 		=> 'philosophy_pro_slider_content_post_active',
	)
);

/**
 * Content type: Catgory
 */ 

// Add category type setting and control
$wp_customize->add_setting( 'philosophy_pro_theme_options[slider_content_category]',array(
		'sanitize_callback' 	=> 'philosophy_pro_sanitize_dropdown_category_list'
	)
);

$wp_customize->add_control( new Philosophy_Pro_Dropdown_Category_Control( $wp_customize, 'philosophy_pro_theme_options[slider_content_category]', 
	array(
		'label'           	=> esc_html__( 'Select Category', 'philosophy-pro' ),
		'description'     	=> esc_html__( 'Slides from selected category will be shown.', 'philosophy-pro' ),
		'section'         	=> 'philosophy_pro_slider_section',
		'active_callback' 	=> 'philosophy_pro_slider_content_category_active',
	)
) );

// Add learn more text setting and control.
$wp_customize->add_setting( 'philosophy_pro_theme_options[slide_learn_more_text]', array(
		'default'           => $options['slide_learn_more_text'],
		'sanitize_callback' => 'sanitize_text_field',
		'transport' 		=> 'postMessage',
	)
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'philosophy_pro_theme_options[slide_learn_more_text]', array(
		'selector'            => '#main-slider a.btn-fill',
		'render_callback'     => 'philisophy_pro_main_slider_learn_more_refresh',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

$wp_customize->add_control( 'philosophy_pro_theme_options[slide_learn_more_text]', array(
		'label'           	=> esc_html__( 'Learn More Text', 'philosophy-pro' ),
		'description'		=> esc_html__( 'Input Learn more button text.', 'philosophy-pro' ),
		'section'         	=> 'philosophy_pro_slider_section',
		'active_callback' 	=> 'philosophy_pro_slider_content_custom_or_demo_not_active',
	)
);