<?php
/**
 * Blog section
 *
 * This is the template for the content of blog section
 *
 * @package Theme_Palace
 * @subpackage Philosophy_Pro
 * @since 1.0
 */

if ( ! function_exists( 'philosophy_pro_add_blog_section' ) ) :
  /**
   * Add blog section
   *
   * @since 1.0
   */
  function philosophy_pro_add_blog_section() {

    // Check if blog section is enabled on frontpage
    $blog_section_enable = apply_filters( 'philosophy_pro_section_status', true, 'blogs_enable' );
    if ( true !== $blog_section_enable ) {
      return false;
    }

    // Get blog section details
    $section_details = array();
    $section_details = apply_filters( 'philosophy_pro_filter_blog_details', $section_details );

    if ( empty( $section_details ) ) {
      return;
    }

    // Render blog section now.
    philosophy_pro_render_blog_section( $section_details );
  }
endif;
add_action( 'philosophy_pro_homepage_section', 'philosophy_pro_add_blog_section', 90 );

if ( ! function_exists( 'philosophy_pro_get_blogs_section_details' ) ) :
  /**
   * Blogs section details.
   *
   * @since 1.0
   * @param array $input Blogs section details.
   */
    function philosophy_pro_get_blogs_section_details( $input ) {
        $options = philosophy_pro_get_theme_options();

        // blog section type
        $content_type = $options['blogs_content_type'];

        $content = array();
        switch ( $content_type ) {
            case 'demo':
                $demo_title = array(
                    esc_html__( 'STUDY STOCK MARKET', 'philosophy-pro'),
                    esc_html__( 'START WORKING WITH MORNING COFFEE', 'philosophy-pro'),
                    esc_html__( 'GREENARY HELPS EYE FOR BETTER VIEW', 'philosophy-pro'),
                    esc_html__( 'VINTAGE TYPEWRITER IS STILL BETTER.', 'philosophy-pro'),
                );

                for ( $i=1; $i<=4 ; $i++ ) {
                    $content[$i]['img_array'][0] = get_template_directory_uri() . '/assets/uploads/blog-0'. $i .'.jpg';
                    $content[$i]['url']          = '#';
                    $content[$i]['title']        = $demo_title[$i-1];
                    $content[$i]['excerpt']      = esc_html__( 'Integer quis mauris tincidunt, tinc idunt lacus id, ultrices neque. Pha sellus consectetur ipsum quis lacus volutpat, eu gravida ante finibus.', 'philosophy-pro' );
                    $content[$i]['post_date']    = esc_html__( 'Oct 22, 2016', 'philosophy-pro' );
                    $content[$i]['author']       = esc_html__( 'Admin', 'philosophy-pro' );
                }
            break;

            case 'posts':
                $posts_ids = array(); // set empty array of posts id
                for( $i=1; $i<=4; $i++ ){
                    if( !empty( $options['blogs_content_posts_'. $i ] ) ){
                        $posts_ids  = array_merge( $posts_ids, array( absint( $options['blogs_content_posts_' . $i] ) ) );
                    }
                }

                // Bail if no valid pages are selected.
                if ( empty( $posts_ids ) ) {
                    return $input;
                }

                $args = array(
                    'post__in'       => $posts_ids,
                    'orderby'        => 'post__in',
                    'posts_per_page' => 4,
                );

                $posts = get_posts( $args ); // get posts 
               
                $i = 1;
                foreach ( $posts as $post ) {
                    $post_id   = $post->ID;
                    $img_array = array();

                    if ( has_post_thumbnail( $post_id ) ) {
                        $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'philosophy-pro-square-thumbnail' );
                    } else {
                        $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-300x300.jpg';
                    }

                    if ( isset( $img_array ) ) {
                        $content[$i]['img_array'] = $img_array;
                    }

                    $content[$i]['url']       = get_permalink( $post_id );
                    $content[$i]['title']     = get_the_title( $post_id );
                    $content[$i]['excerpt']   = philosophy_pro_trim_content( 20, $post );
                    $content[$i]['post_date'] = get_the_date( '', $post_id );
                    $content[$i]['author']    = get_the_author_meta( 'display_name', $post->post_author );
                $i++;
                }
            break;

            case 'category':
                $cat_ids = ! empty( $options['blogs_content_category'] ) ? $options['blogs_content_category'] : array(); // get blog categories

                // Bail if no valid categories are selected.
                if ( empty( $cat_ids ) ) {
                    return $input;
                }

                $args = array(
                    'category__in'        => $cat_ids,
                    'posts_per_page'      => 4,
                    'orderby'             => 'DESC',
                    'ignore_sticky_posts' => true
                );

                $category_posts = get_posts( $args );

                if( !empty( $category_posts ) ){
                    $i = 1;
                    foreach( $category_posts as $category_post ) :
                        $post_id   = $category_post->ID;
                        $author_id = $category_post->post_author;
                        $img_array = array();

                        if ( has_post_thumbnail( $post_id ) ) {
                            $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'philosophy-pro-square-thumbnail' );
                        } else {
                            $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-300x300.jpg';
                        }   

                        $content[$i]['img_array'] = $img_array;
                        $content[$i]['url']       = get_permalink( $post_id );
                        $content[$i]['title']     = get_the_title( $post_id );
                        $content[$i]['excerpt']   = philosophy_pro_trim_content( 20, $category_post );
                        $content[$i]['post_date'] = get_the_date( '', $post_id );
                        $content[$i]['author']    = get_the_author_meta( 'display_name', $author_id );

                        $i++;
                    endforeach;
                }
            break;

            default:
            break;
        }

        if ( ! empty( $content ) ) {
          $input = $content;
        }
        return $input;
    }
endif;
// Blogs section content details.
add_filter( 'philosophy_pro_filter_blog_details', 'philosophy_pro_get_blogs_section_details' );


if ( ! function_exists( 'philosophy_pro_render_blog_section' ) ) :
  /**
   * Start blog section
   *
   * @return string blog section content
   * @since 1.0
   *
   */
   function philosophy_pro_render_blog_section( $content_details ) {
        $options = philosophy_pro_get_theme_options(); // Get theme options

        $section_title    = !empty( $options['blogs_title'] ) ? $options['blogs_title'] : ''; // Get blog section title
        $section_subtitle = !empty( $options['blogs_subtitle'] ) ? $options['blogs_subtitle'] : ''; // Get blog subtitle

        $heading_box_layout = ( true == $options['enable_heading_box_layout'] ) ? 'add-gray-border border-center' : '';
    ?>
        <section id="blog" class="page-section blog-text">
            <div class="wrapper">

                <?php if( !empty( $section_title ) || !empty( $section_subtitle ) ) : ?>
                    <header class="entry-header text-center <?php echo esc_attr( $heading_box_layout ); ?>">
                        <?php 
                            if( !empty( $section_title ) ){
                                echo '<h2 class="entry-title">'. esc_html( $section_title ) .'</h2>';
                            }

                            if( !empty( $section_subtitle ) ){
                                echo '<h3 class="sub-title">'. esc_html( $section_subtitle ) .'</h3>';
                            }
                        ?>
                    </header><!--.entry-header-->
                <?php endif; ?>

                <div class="entry-content col-4">
                    <div class="row blog-text">
                    <?php foreach( $content_details as $content ) : ?>
                        <div class="column-wrapper">
                            <?php
                                if( !empty( $content['img_array'] ) ){
                                    $blog_background_css = "style='background-image: url(". esc_url( $content['img_array'][0] ) .");'";
                                } else{
                                    $blog_background_css = '';
                                }
                            ?>
                            <div class="featured-image" <?php echo $blog_background_css; ?>>
                                <div class="blue-overlay"></div>
                                <div class="hover-content">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="view-more"><span data-hover="Read More"><?php esc_html_e( 'Read More', 'philosophy-pro' ); ?></span></a>
                                    <span class="link-more"></span>
                                </div><!--.hover-content-->
                            </div><!--.featured-image-->

                            <div class="blog-wrapper">
                                <div class="blog-content">
                                    <?php if( !empty( $content['title'] ) ){ ?>
                                        <h4><a href="<?php echo esc_url( $content['url'] );?>"><?php echo esc_html( $content['title'] ); ?></a></h4>
                                    <?php } ?>
                                    <div class="seperator"></div>
                                    <?php 
                                        if( !empty( $content['excerpt'] ) ) {
                                            echo '<p>'. esc_html( $content['excerpt'] ) .'</p>';
                                        }
                                    ?>
                                </div><!--.blog-content-->

                                <div class="article-entry-meta">
                                    <time><?php echo date_i18n( esc_html__( 'M d, Y', 'philosophy-pro' ), strtotime( $content['post_date'] ) );?></time>
                                      /
                                    <span><?php echo esc_html( $content['author'] ); ?></span>
                                </div><!--article / entry-meta-->
                            </div><!--.blog-wrapper-->
                        </div><!--.column-wrapper-->
                    <?php endforeach; ?>

                    </div><!--.row-->
                </div><!--.entry-content-->
            </div><!--.wrapper-->
        </section><!-- #blog -->
    <?php 
    }
endif;