<?php
/**
 * Contact section
 *
 * This is the template for the content of contact section
 *
 * @package Theme_Palace
 * @subpackage Philosophy_Pro
 * @since 1.0
 */
if ( ! function_exists( 'philosophy_pro_add_contact_section' ) ) :
    /**
     * Add contact section
     *
     * @since 1.0
     */

    function philosophy_pro_add_contact_section() {
        // Check if contact section is enabled on frontpage
        $contact_section_enable = apply_filters( 'philosophy_pro_section_status', true, 'contact_enable' );

        if ( true !== $contact_section_enable ) {
            return false;
        }

        // Render contact section
        philosophy_pro_render_contact_section();

    }
endif;
add_action( 'philosophy_pro_homepage_section_footer', 'philosophy_pro_add_contact_section', 10 );


if ( ! function_exists( 'philosophy_pro_render_contact_section' ) ) :
    /**
     * Start contact section
     *
     * @return string contact section content
     * @since 1.0
     *
     */
    function philosophy_pro_render_contact_section() {
        $options = philosophy_pro_get_theme_options();
        $content_type = $options['contact_content_type']; 

        switch ( $content_type ) {
            case 'demo':
                $contact_title    = esc_html__( 'Contact', 'philosophy-pro' );
                $contact_subtitle = esc_html__( 'Let&rsquo;s Talk.', 'philosophy-pro' );

                $address_label    = esc_html__( 'Address', 'philosophy-pro' );
                $address_text     = esc_html__( 'jawlakhel, Kathmandu, Nepal', 'philosophy-pro' );
                $phone_label      = esc_html__( 'Phone No:', 'philosophy-pro' );
                $phone_number     = '+977-123456789';
                $email_label       = esc_html__( 'Email:', 'philosophy-pro' );
                $email_id         = 'info@themepalace.com';
                $background_src   = get_template_directory_uri().'/assets/uploads/contact-bg.jpg';
            break;
            
            default:
                $contact_title    = ! empty( $options['contact_custom_title'] ) ? $options['contact_custom_title'] : '';
                $contact_subtitle = ! empty( $options['contact_subtitle'] ) ? $options['contact_subtitle'] : '';
                $address_label     = ! empty( $options['contact_address_label'] ) ? $options['contact_address_label'] : '';
                $address_text     = ! empty( $options['contact_address'] ) ? $options['contact_address'] : '';
                $phone_label       = ! empty( $options['contact_phone_label'] ) ? $options['contact_phone_label'] : '';
                $phone_number     = ! empty( $options['contact_phone_number'] ) ? $options['contact_phone_number'] : '';
                $email_label       = ! empty( $options['contact_email_label'] ) ? $options['contact_email_label'] : '';
                $email_id         = ! empty( $options['contact_email'] ) ? $options['contact_email'] : '';
                $background_src   = ! empty( $options['contact_background_image'] ) ? $options['contact_background_image'] : '';
            break;
        }

        $background_style = '';
        if ( ! empty( $background_src ) ){
            $background_style = 'style="background-image: url('. esc_url( $background_src ) .')"';
        }

        $heading_box_layout = ( true == $options['enable_heading_box_layout'] ) ? 'add-gray-border' : '';
    ?>
    <section id="contact" class="col-2">
        <div class="row">
            <div class="column-wrapper" <?php echo $background_style; ?>>
                <div class="page-section">
                    <div class="black-overlay"></div>

                        <?php if ( ! empty( $contact_title ) || ! empty( $contact_subtitle ) ) : ?>
                            <header class="entry-header text-center <?php echo esc_attr( $heading_box_layout ); ?>">
                                <?php
                                    if ( ! empty( $contact_title ) ) {
                                        echo '<h2 class="entry-title color-white">'. esc_html( $contact_title ) .'</h2>';
                                    }
                                    if ( ! empty( $contact_subtitle ) ) {
                                        echo '<h3 class="sub-title">'. esc_html( $contact_subtitle ) .'</h3>';
                                    }
                                ?>
                            </header><!--.entry-header-->
                        <?php endif; ?>

                        <div class="entry-content">
                            <ul class="address-block">
                                <?php if ( ! empty( $address_label ) || ! empty( $address_text ) ) : ?>
                                    <li class="address">
                                        <?php 
                                            
                                            echo '<i class="fa fa-map-marker"></i>';

                                            if ( ! empty( $address_label ) ) {
                                                echo '<label>'. esc_html( $address_label ). '</label>';
                                            }

                                            if ( ! empty( $address_text ) ){
                                                echo '<span>'. esc_html( $address_text ) .'</span>';
                                            }
                                        ?>
                                    </li>
                                <?php endif; ?>

                                <?php if ( ! empty( $phone_label ) || ! empty( $phone_number ) ) : ?>
                                    <li class="phone">
                                        <?php 
                                            echo '<i class="fa fa-phone"></i>';

                                            if ( ! empty( $phone_label ) ) {
                                                echo '<label>'. esc_html( $phone_label ). '</label>';
                                            }
                                        
                                            if ( ! empty( $phone_number ) ) {
                                                echo '<span><a href="tel:'. esc_attr( preg_replace('/\D+/', '', $phone_number ) ) .'">'. esc_html( $phone_number ) .'</a></span>';
                                            }
                                        ?>
                                        
                                    </li>
                                <?php endif; ?>

                                <?php if ( ! empty( $email_label ) || ! empty( $email_id ) ) : ?>
                                    <li class="email">
                                        <?php 
                                            echo '<i class="fa fa-envelope"></i>';

                                            if ( ! empty( $email_label ) ){
                                                echo '<label>'. esc_html( $email_label ). '</label>';
                                            }

                                            if ( ! empty( $email_id ) ){
                                                echo '<span><a href="mailto:'. esc_url( $email_id ) .'">'. esc_html( $email_id ) .'</a></span>';
                                            }
                                        ?>
                                    </li>
                                <?php endif; ?>
                            </ul>
                        </div><!--.entry-content-->
                </div><!-- .page-section -->
            </div><!--.column-wrapper-->
            <?php if ( 'demo' == $content_type ) : ?>
                <div class="column-wrapper">
                    <div class="form-wrapper clear">
                
                        <div role="form" class="wpcf7" id="wpcf7-f21-p2-o1" lang="en-US" dir="ltr">
                            <div class="screen-reader-response"></div>
                            <form action="#">
                                <p><label><?php esc_html_e( 'Your Name (required)', 'philosophy-pro' ); ?><br>
                                    <span class="wpcf7-form-control-wrap your-name"><input type="text" name="First-name" value="" size="40" class="wpcf7-form-control wpcf7-text wpcf7-validates-as-required" aria-required="true" aria-invalid="false"></span> </label></p>
                                <p><label> <?php esc_html_e( 'Your Email (required)', 'philosophy-pro' ); ?><br>
                                    <span class="wpcf7-form-control-wrap your-email"><input type="email" name="your-email" value="" size="40" class="wpcf7-form-control wpcf7-text wpcf7-email wpcf7-validates-as-required wpcf7-validates-as-email" aria-required="true" aria-invalid="false"></span> </label></p>
                                <p><label><?php esc_html_e( 'Subject', 'philosophy-pro' ); ?> <br>
                                    <span class="wpcf7-form-control-wrap your-subject"><input type="text" name="your-subject" value="" size="40" class="wpcf7-form-control wpcf7-text" aria-invalid="false"></span> </label></p>
                                <p><label><?php esc_html_e( 'Your Message', 'philosophy-pro' ); ?><br>
                                    <span class="wpcf7-form-control-wrap your-message"><textarea name="your-message" cols="40" rows="10" class="wpcf7-form-control wpcf7-textarea" aria-invalid="false"></textarea></span> </label></p>
                                <p><input type="submit" value="<?php esc_html_e( 'Send', 'philosophy-pro' ); ?>" class="wpcf7-form-control wpcf7-submit">
                                <div class="wpcf7-response-output wpcf7-display-none"></div>
                            </form>
                        </div><!-- .wpcf7 -->

                        <ul class="social-icon">
                            <li><a href="<?php echo esc_url( 'www.facebook.com' ); ?>"><?php esc_html_e( 'facebook', 'philosophy-pro' ); ?></a></li>
                            <li><a href="<?php echo esc_url( 'www.twitter.com' ); ?>"><?php esc_html_e( 'twitter', 'philosophy-pro' ); ?></a></li>
                            <li><a href="<?php echo esc_url( 'www.plus.google.com' ); ?>"><?php esc_html_e( 'plusgoogle', 'philosophy-pro' ); ?></a></li>
                            <li><a href="<?php echo esc_url( 'www.pinterest.com' ); ?>"><?php esc_html_e( 'pinterest', 'philosophy-pro' ); ?></a></li>
                        </ul>

                    </div><!--form-wrapper-->
                </div><!--.column-wrapper-->
            <?php else: 
                if ( ! empty( $options['contact_form_shortcode'] ) ) { 
                ?>
                <div class="column-wrapper">
                    <div class="form-wrapper clear">
                
                        <?php 
                            echo do_shortcode( wp_kses_post( $options['contact_form_shortcode'] ) );

                            if ( $options['enable_social_links'] ) :

                                echo '<ul class="social-icon">';

                                for( $i=1; $i<= $options['no_of_social_link']; $i++ ){
                                    $social_link  =  !empty( $options['social_link_'. $i ] ) ? $options['social_link_'. $i ] : '';
                                    if( !empty( $social_link ) ){
                                        echo '<li><a href="'. esc_url( $social_link ).'"></a></li>';
                                    }
                                }

                                echo '</ul>';
                            endif; ?>
                    </div><!--form-wrapper-->
                </div><!--.column-wrapper-->
            <?php
                }
                endif;
            ?>

        </div><!--.row-->
    </section><!-- #contact-->
    <?php 
    }
endif;