<?php
/**
 * Counter section
 *
 * This is the template for the content of counter section
 *
 * @package Theme_Palace
 * @subpackage Philosophy_Pro
 * @since 1.0
 */
if ( ! function_exists( 'philosophy_pro_add_counter_section' ) ) :
  /**
   * Add counter section
   *
   * @since 1.0
   */
   function philosophy_pro_add_counter_section() {

    // Check if counter section is enabled on frontpage
    $counter_section_enable = apply_filters( 'philosophy_pro_section_status', true, 'counter_enable' );
    if ( true !== $counter_section_enable ) {
      return false;
    }

    // Get counter section details
    $section_details = array();
    $section_details = apply_filters( 'philosophy_pro_filter_counter_details', $section_details );

    if ( empty( $section_details ) ) {
      return;
    }

    // Render counter section now.
    philosophy_pro_render_counter_section( $section_details );
  }
endif;
add_action( 'philosophy_pro_homepage_section', 'philosophy_pro_add_counter_section', 70 );

if ( ! function_exists( 'philosophy_pro_get_counter_section_details' ) ) :
  /**
   * counter section details.
   *
   * @since Philosophy Pro 1.0
   * @param array $input counter section details.
   */
   function philosophy_pro_get_counter_section_details( $input ) {
        $options = philosophy_pro_get_theme_options();

        // counter type
        $counter_content_type  = $options['counter_content_type'];

        $content = array();
        switch ( $counter_content_type ) {
            case 'demo':
                $icons = array( 'fa-coffee', 'fa-briefcase', 'fa-calendar' , 'fa-group' );
                $title = array( 
                    esc_html__( 'COFFEE CUPS', 'philosophy-pro' ), 
                    esc_html__( 'PROJECTS', 'philosophy-pro' ), 
                    esc_html__( 'WORKING DAYS', 'philosophy-pro' ),
                    esc_html__( 'CLIENTS', 'philosophy-pro' ) 
                );

                for ( $i=0; $i< 4; $i++ ) {
                    $content[$i]['icon']   = $icons[ $i ];
                    $content[$i]['title']  = $title[ $i ];
                    $content[$i]['number'] = esc_html__( '999', 'philosophy-pro');
                }
            break;

            case 'custom':
                $content_layout  = !empty( $options['counter_section_layout'] ) ? $options['counter_section_layout'] : 'four-columns'; // check counter section layout
                $counter_count = ( 'three-columns' == $content_layout ) ? 3 : 4; 

                for( $i = 1; $i <= $counter_count; $i++ ){

                    $content[$i]['icon']   = !empty( $options['counter_icon_'.$i] ) ? $options['counter_icon_'.$i] : '';
                    $content[$i]['title']  = !empty( $options['counter_name_'.$i] ) ? $options['counter_name_'.$i] : '';
                    $content[$i]['number'] = !empty( $options['counter_count_'.$i] ) ? $options['counter_count_'.$i] : '';

                }
          break;

          default:
          break;
        }

        if ( !empty( $content ) ) {
          $input = $content;
        }

        return $input;
  }
endif;
// counter section content details.
add_filter( 'philosophy_pro_filter_counter_details', 'philosophy_pro_get_counter_section_details' );


if ( ! function_exists( 'philosophy_pro_render_counter_section' ) ) :
  /**
   * Start counter section
   *
   * @return string counter section content
   * @since 1.0
   *
   */
    function philosophy_pro_render_counter_section( $content_details ) {
        $options = philosophy_pro_get_theme_options(); // Get theme options
        $counter_background = !empty( $options['counter_background_image'] ) ? $options['counter_background_image'] : '';

        if( !empty( $counter_background ) ){
            $counter_background_inline_css = "style='background-image: url(". esc_url( $counter_background ) .");'";
        }else{
            $counter_background_inline_css = '';
        }

        $content_layout = !empty( $options['counter_section_layout'] ) ? $options['counter_section_layout'] : 'four-columns'; // check counter section layout
        $counter_layout_class = ( 'three-columns' == $content_layout ) ? 'col-3' : 'col-4'; 
    ?>
        <section id="counter" class="page-section" <?php echo $counter_background_inline_css; ?> data-stellar-background-ratio="0.5" data-stellar-vertical-offset="0">
            <div class="black-overlay"></div>
            <div class="wrapper">
                <div class="statscounts text-center <?php echo esc_attr( $counter_layout_class ); ?>">
                    <div class="row">
                    <?php foreach ( $content_details as $content ) : ?>
                        <div class="column-wrapper">
                            <div class="statwrap">
                                <?php 
                                    if( !empty( $content['icon'] ) ){
                                        echo '<i class="fa '. esc_attr( $content['icon'] ) .'"></i>';
                                    }

                                    if( !empty( $content['title'] ) ){
                                        echo '<small>'. esc_html( $content['title'] ) .'</small>';
                                    }

                                    if( !empty( $content['number'] ) ){
                                        echo '<span class="stat-count count-1">'. absint( $content['number'] ) .'</span>';
                                    }
                                ?>
                            </div><!-- .statwrap -->
                        </div><!-- .column-wrapper-->
                    <?php endforeach; ?>
            
                    </div><!--.row-->              
                </div><!-- .statscounts/ col-4 -->
            </div><!-- .wrapper -->
        </section><!-- #counter -->
    <?php 
    }
endif;