<?php
/**
 * testimonials section
 *
 * This is the template for the content of testimonials section
 *
 * @package Theme_Palace
 * @subpackage Philosophy_Pro
 * @since 1.0
 */
if ( ! function_exists( 'philosophy_pro_add_testimonials_section' ) ) :
  /**
   * Add testimonials section
   *
   * @since 1.0
   */
  function philosophy_pro_add_testimonials_section() {

    // Check if testimonials section is enabled on frontpage
    $testimonials_section_enable = apply_filters( 'philosophy_pro_section_status', true, 'testimonial_enable' );

    if ( true !== $testimonials_section_enable ) {
      return false;
    }

    // Get testimonials section details
    $section_details = array();
    $section_details = apply_filters( 'philosophy_pro_filter_testimonials_details', $section_details );

    if ( empty( $section_details ) ) {
      return;
    }

    // Render testimonials section now.
    philosophy_pro_render_testimonials_section( $section_details );
  }
endif;
add_action( 'philosophy_pro_testimonial_section', 'philosophy_pro_add_testimonials_section', 10 );

if ( ! function_exists( 'philosophy_pro_get_testimonial_section_details' ) ) :
    /**
     * Testimonal section details.
     *
     * @since Philosophy Pro 1.0
     * @param array $input Testimonial section details.
     */

    function philosophy_pro_get_testimonial_section_details( $input ) {
        $options = philosophy_pro_get_theme_options();

        // Testimonal section type
        $testimonial_content_type = $options['testimonial_content_type'];
        $no_of_slides = !empty( $options['testimonial_no_of_slides'] ) ? absint( $options['testimonial_no_of_slides'] ) : 5;

        $content = array();

        switch ( $testimonial_content_type ) {
            case 'demo':

                for ( $i=1; $i<=3; $i++ ) {
                    $content[$i]['ID']           = '';
                    $content[$i]['img_array'][0] = get_template_directory_uri() . '/assets/uploads/testimonial-01.jpg';
                    $content[$i]['url']          = '#';
                    $content[$i]['thought']      = esc_html__( 'Nunc venenatis felis metus, quis cursus massa gravida vel. Suspendisse potenti. Morbi sollicitudin eu nisl quis venenatis. Nullam rutrum, nisl at vehicula ultricies, ex nisl bibendum dui, ac blandit elit nunc et felis. Donec ultrices posuere quam sit amet tincidunt. Mauris feugiat mattis scelerisque.', 'philosophy-pro' );
                    $content[$i]['testimonial_name']  = esc_html( 'Sandeep Regmi', 'philosophy-pro' );
                    $content[$i]['position']     = esc_html__( 'Developer', 'philosophy-pro' );
                }
            break;

            case 'posts':

                $testimonial_post_ids = ! empty( $options['testimonial_post_ids'] ) ?  $options['testimonial_post_ids'] : array(); // Get post ids

                // Bial if no post id is entered
                if ( empty( $testimonial_post_ids ) ){
                    return;
                }

                $args = array(
                    'post_type'      => 'post',
                    'post__in'       => $testimonial_post_ids,
                    'orderby'        => 'post__in',
                    'posts_per_page' => absint( $no_of_slides ),
                );

                $testimonial_posts = get_posts( $args );

                $i = 1;
                foreach ( $testimonial_posts as $testimonial_post ) {
                    $img_array = null;

                    if ( has_post_thumbnail( $testimonial_post->ID ) ) {
                        $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $testimonial_post->ID ), 'philosophy-pro-square-thumbnail' );
                    } else {
                        $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-300x300.jpg';
                    }

                    $content[$i]['img_array'] = $img_array;
                    $content[$i]['ID']        = $testimonial_post->ID;
                    $content[$i]['url']       = get_permalink( $testimonial_post->ID );
                    $content[$i]['thought']   = philosophy_pro_trim_content( 40, $testimonial_post );
                    $content[$i]['testimonial_name']     = get_the_title( $testimonial_post->ID );
                    $content[$i]['position']  = '';

                    $i++;
                }
            break;

            case 'page':
                $testimonial_page_ids = array(); // Initialize a empty array
                for( $i=1; $i<=$no_of_slides; $i++ ){
                    $post_id = !empty( $options['testimonial_page_id_'. $i ] ) ? absint( $options['testimonial_page_id_'. $i ] ) : '';
                    $testimonial_page_ids = array_merge( $testimonial_page_ids, array( $post_id ) );
                }

                $args = array(
                    'post_type'      => 'page',
                    'post__in'       => $testimonial_page_ids,
                    'orderby'        => 'post__in',
                    'posts_per_page' => absint( $no_of_slides ),
                );

                $testimonial_pages = get_posts( $args );

                $i = 1;
                foreach ( $testimonial_pages as $testimonial_page ) {
                    $img_array = null;

                    if ( has_post_thumbnail( $testimonial_page->ID ) ) {
                        $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $testimonial_page->ID ), 'philosophy-pro-square-thumbnail' );
                    } else {
                        $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-300x300.jpg';
                    }

                    $content[$i]['img_array'] = $img_array;
                    $content[$i]['ID']        = $testimonial_page->ID;
                    $content[$i]['url']       = get_permalink( $testimonial_page->ID );
                    $content[$i]['thought']   = philosophy_pro_trim_content( 40, $testimonial_page );
                    $content[$i]['testimonial_name']     = get_the_title( $testimonial_page->ID );
                    $content[$i]['position']  = '';

                    $i++;
                }
            break;

            case 'category':
                // Fetch posts.
                $category_ids = !empty( $options['testimonial_content_category'] ) ? $options['testimonial_content_category'] : array();

                if( empty( $category_ids ) ){
                    return;
                }
                $args = array( 
                    'category__in'        => $category_ids,
                    'posts_per_page'      => absint( $no_of_slides ),
                    'ignore_sticky_posts' => true
                );

                $testimonial_category = get_posts( $args );

                $i = 1;
                foreach ( $testimonial_category as $testimonial_cat_post ) {
                    $img_array = null;

                    if ( has_post_thumbnail( $testimonial_cat_post->ID ) ) {
                        $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $testimonial_cat_post->ID ), 'philosophy-pro-square-thumbnail' );
                    } else {
                        $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-300x300.jpg';
                    }

                    $content[$i]['img_array'] = $img_array;
                    $content[$i]['ID']        = $testimonial_cat_post->ID;
                    $content[$i]['url']       = get_permalink( $testimonial_cat_post->ID );
                    $content[$i]['thought']   = philosophy_pro_trim_content( 40, $testimonial_cat_post );
                    $content[$i]['testimonial_name']     = get_the_title( $testimonial_cat_post->ID );
                    $content[$i]['position']  = '';

                    $i++;
                }
            break;

            case 'tp-philosophy-testimonial':

                $cpt_testimonial_post_ids = !empty( $options['cpt_testimonial_post_ids'] ) ? $options['cpt_testimonial_post_ids'] : array(); // Get cpt post IDs

                // Bial if no post ids is entered
                if( empty( $cpt_testimonial_post_ids ) ){
                    return;
                }

                $args = array(
                    'post_type'      => 'tp-philosophy-testi',
                    'post__in'       => $cpt_testimonial_post_ids,
                    'orderby'        => 'post__in',
                    'posts_per_page' => absint( $no_of_slides ),
                );

                $cpt_testimonial_posts = get_posts( $args );

                $i = 1;
                foreach ( $cpt_testimonial_posts as $cpt_testimonial_post ) {
                    $img_array = null;

                    if ( has_post_thumbnail( $cpt_testimonial_post->ID ) ) {
                        $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $cpt_testimonial_post->ID ), 'philosophy-pro-square-thumbnail' );
                    } else {
                        $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-300x300.jpg';
                    }
                    $testimonial_designation = get_post_meta( $cpt_testimonial_post->ID, 'tp_philosophy_testimonial_designation_value', true );

                    $content[$i]['img_array'] = $img_array;
                    $content[$i]['ID']        = $cpt_testimonial_post->ID;
                    $content[$i]['url']       = get_permalink( $cpt_testimonial_post->ID );
                    $content[$i]['thought']   = philosophy_pro_trim_content( 50, $cpt_testimonial_post );
                    $content[$i]['testimonial_name'] = get_the_title( $cpt_testimonial_post->ID );
                    $content[$i]['position']  = !empty( $testimonial_designation ) ? $testimonial_designation : '';

                    $i++;
                }
            break;

            default:
            break;
        }

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// teams course section content details.
add_filter( 'philosophy_pro_filter_testimonials_details', 'philosophy_pro_get_testimonial_section_details' );

if ( ! function_exists( 'philosophy_pro_render_testimonials_section' ) ) :
  /**
   * Start testimonials section
   *
   * @return string testimonials section content
   * @since 1.0
   *
   */
   function philosophy_pro_render_testimonials_section( $content_details ) { 
        $options = philosophy_pro_get_theme_options(); // Get theme options

        // Get testimonial background inline css
        if( !empty( $options['testimonial_background_image'] ) ){
            $testimonial_background_inline_css = "style='background-image: url(".esc_url( $options['testimonial_background_image'] ) .");'";
        }else{
            $testimonial_background_inline_css = '';
        } 
        ?>
        <div class="column-wrapper" <?php echo $testimonial_background_inline_css; ?>>
            <div class="page-section">
                <div class="testimonial-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, 
              "infinite": false, "speed": 600,  "dots": true, "arrows":false, "autoplay": true, "fade": false, "draggable":false}'>

                    <?php foreach( $content_details as $content ) : ?>
                        <div class="testimonial-contents">
                            <div class="icon-quote">
                                <img src="<?php echo get_template_directory_uri(); ?>/assets/uploads/icon-quote.png" alt="<?php esc_html_e( 'Icon', 'philosophy-pro' ); ?>">
                            </div><!--.icon-quote-->
                            <?php 
                                if( !empty( $content['thought'] ) ){
                                    echo '<blockquote>'. esc_html( $content['thought'] ) .'</blockquote>';
                                }
                            ?>
                            <div class="developer">
                                <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['img_array'][0] ); ?>" alt="<?php echo esc_attr( $content['testimonial_name'] ); ?>"></a>
                                <a href="<?php echo esc_url( $content['url'] ); ?>" class="client-name"><?php echo esc_html( $content['testimonial_name'] ); ?></a>
                                <?php 
                                    if( ! empty( $content['position'] ) ){
                                        echo '<span class="client-position">'. esc_html( $content['position'] ) .'</span>';
                                    }
                                ?>
                                
                            </div><!--.developer-->
                        </div><!--.testimonial-contents-->
                    <?php endforeach; ?>
              </div><!--.testimonial-slider-->
            </div><!-- .page-section -->
          </div><!--.column-wrapper-->
    <?php 
    }
endif;