<?php
/**
 * Work section
 *
 * This is the template for the content of work section
 *
 * @package Theme_Palace
 * @subpackage Philosophy_Pro
 * @since 1.0
 */
if ( ! function_exists( 'philosophy_pro_add_work_section' ) ) :
    /**
     * Add work section
     *
     * @since 1.0
     */
    function philosophy_pro_add_work_section() {
        // Check if work section is enabled on frontpage
        $work_section_enable = apply_filters( 'philosophy_pro_section_status', true, 'works_enable' );

        if ( true !== $work_section_enable ) {
            return false;
        } ?>
        <section id="work" class="col-2">
            <div class="row">
                
                <?php 
                    /**
                     * philosophy_pro_work_title_content hook
                     *
                     * @hooked philosophy_pro_work_title_column -  10
                     */
                    do_action( 'philosophy_pro_work_title_content' );

                    /**
                     * philosophy_pro_work_section_content hook
                     *
                     * @hooked philosophy_pro_work_column_content -  10
                     */
                    do_action( 'philosophy_pro_work_section_content' );
                ?>

            </div><!--.row-->
        </section><!-- #work -->
    <?php
    }
endif;
add_action( 'philosophy_pro_homepage_section', 'philosophy_pro_add_work_section', 50 );
/**
 * Functions and filters to add works section title
 */
if( ! function_exists( 'philosophy_pro_work_title_column' ) ) :
    /**
     * Add work column content
     *
     * @since 1.0
     */
    function philosophy_pro_work_title_column(){
        $options      = philosophy_pro_get_theme_options();
        $content_type = $options['works_content_type'];

        switch ( $content_type ) {
            case 'demo' :
                $section_title       = esc_html__( 'Work', 'philosophy-pro' );
                $section_subtitle    =  esc_html__( 'Flawless Output', 'philosophy-pro' );
                $section_description = esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Mauris et iaculis sapien, ac dictum ligula. Integer non bibendum dui, non bibendum tortor.', 'philosophy-pro' );
                $section_quote       = sprintf( '<blockquote>%1$s</blockquote>
                <a href="#" class="worker-name">%2$s</a>', esc_html__( '&ldquo; The Business Bio-graphy team refined our brand, and designed a web site that we&rsquo;re proud of.', 'philosophy-pro' ), esc_html__( '-Sandeep Regmi, Themepalace.com', 'philosophy-pro' ) );
                $readmore_text       = esc_html__( 'View All Works', 'philosophy-pro' );
                $readmore_link       = '#';
            break;
            
            case 'page' :
                $section_title       = '';
                $section_subtitle    = ! empty( $options['works_subtitle'] ) ? $options['works_subtitle'] : '';
                $section_description = '';
                $section_quote       = ! empty( $options['works_custom_quote'] ) ? $options['works_custom_quote'] : '';

                $readmore_text       = ! empty( $options['works_learn_more_text'] ) ? $options['works_learn_more_text'] : '';
                $readmore_link       = ! empty( $options['works_custom_link'] ) ? $options['works_custom_link'] : '#';

                // get page id
                $page_id =  ! empty( $options['works_page_id'] ) ? $options['works_page_id'] : '';

                if ( ! empty( $page_id ) ){
                    $work_page           = get_page( $page_id );
                    $page_id             = $work_page->ID;
                    
                    $section_title       = get_the_title( $page_id );
                    $section_description = philosophy_pro_trim_content( 15, $work_page );
                }
            break;

            case 'custom' :
                $section_title       = ! empty( $options['works_custom_title'] ) ? $options['works_custom_title'] : '';
                $section_subtitle    = ! empty( $options['works_subtitle'] ) ? $options['works_subtitle'] : '';
                $section_description = ! empty( $options['works_custom_description'] ) ? $options['works_custom_description'] : '';
                $section_quote       = ! empty( $options['works_custom_quote'] ) ? $options['works_custom_quote'] : '';

                $readmore_text       = ! empty( $options['works_learn_more_text'] ) ? $options['works_learn_more_text'] : '';
                $readmore_link       = ! empty( $options['works_custom_link'] ) ? $options['works_custom_link'] : '#';
            break;

            default:
                # code...
            break;
        }

        ?>
        <div class="column-wrapper">
            <div class="page-section">
                <?php if ( ! empty( $section_title ) || ! empty( $section_subtitle ) ) :
                $heading_box_layout = ( true == $options['enable_heading_box_layout'] ) ? 'add-gray-border' : '';
                ?>
                    <header class="entry-header <?php echo esc_attr( $heading_box_layout ); ?>">
                        <?php
                            if ( !empty( $section_title ) ){
                                echo '<h2 class="entry-title">'. esc_html( $section_title ) .'</h2>';
                            }

                            if ( !empty( $section_subtitle ) ){
                                echo '<h3 class="sub-title">'. esc_html( $section_subtitle ) .'</h3>';
                            }
                        ?>
                    </header><!--.entry-header-->
                <?php endif; ?>

                <div class="entry-content">
                    <?php 
                        if ( !empty( $section_quote ) ){ 
                            echo wp_kses_post( $section_quote );
                        }

                        if ( ! empty( $section_description ) ){
                            echo '<p>'. esc_html( $section_description ) .'</p>';
                        }

                        if ( ! empty( $readmore_text ) ) {
                            echo '<a href="'. esc_url( $readmore_link ) .'" class="view-more"><span data-hover="'. esc_attr( $readmore_text ) .'">'. esc_html( $readmore_text ) .'</span></a>';
                        }

                        if( !empty( $section_title ) ){ ?>
                        <div class="background-text">
                            <?php echo '<h1>'. esc_html( $section_title ) .'</h1>'; ?>
                        </div><!-- .background-text -->
                    <?php } ?>
                </div><!--.entry-content-->
            </div><!-- .margin-top-->
        </div><!--.column-wrapper-->
        <?php
    }
endif;
add_action( 'philosophy_pro_work_title_content', 'philosophy_pro_work_title_column', 10 );

/**
 * Functions and filters to add works content
 */
if( ! function_exists( 'philosophy_pro_work_column_content' ) ) :
    /**
     * Add work column content
     *
     * @since 1.0
     */
    function philosophy_pro_work_column_content( ){
        // Get work section details
        $section_details = array();
        $section_details = apply_filters( 'philosophy_pro_filter_work_container', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }
        // Render work section
        philosophy_pro_render_work_section( $section_details );
    }
endif;
add_action( 'philosophy_pro_work_section_content', 'philosophy_pro_work_column_content', 10 );

if( ! function_exists( 'philosophy_pro_get_works_section_details' ) ) :
    /**
     * Works section details.
     *
     * @since 1.0
     * @param array $input works section details.
     */

    function philosophy_pro_get_works_section_details( $input ) {
        $options = philosophy_pro_get_theme_options(); // Get theme options

        // Works section options
        $works_content_type     = $options['works_content_type'];        
        $content = array();

        switch ( $works_content_type ) {
            case 'demo':
                $image_index = 1;
                for ( $i=1 ; $i<=9; $i++ ) {

                    $content[$i]['img_array'][0] = get_template_directory_uri() . '/assets/uploads/work-0'. $image_index .'.jpg';
                    $content[$i]['url']        = '#';
                    $content[$i]['title']      = esc_html__( 'Leather bag', 'philosophy-pro' );
                    
                    $image_index++;

                    if ( $i % 2 == 0 ){
                        $image_index = 1;
                    }

                }

            break;
            
            default:
                // Fetch posts.
                $category_ids = ! empty( $options['works_content_category'] ) ? $options['works_content_category'] : array();

                if( empty( $category_ids ) ){
                    return;
                }
                $args = array( 
                    'category__in'        => $category_ids,
                    'posts_per_page'      => 9,
                    'ignore_sticky_posts' => true
                );

                $works_category = get_posts( $args );

                $i = 1;
                foreach ( $works_category as $works_cat_post ) {
                    $img_array = null;

                    if ( has_post_thumbnail( $works_cat_post->ID ) ) {
                        $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $works_cat_post->ID ), 'philosophy-pro-square-thumbnail' );
                    } else {
                        $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-300x300.jpg';
                    }

                    $content[$i]['img_array'] = $img_array;
                    $content[$i]['title']     = get_the_title( $works_cat_post->ID );
                    $content[$i]['url']       = get_permalink( $works_cat_post->ID );

                    $i++;
                }
            break; 
        }
                                                                                                                   
        if ( !empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
add_filter( 'philosophy_pro_filter_work_container', 'philosophy_pro_get_works_section_details' );

// Render work section now.
if ( ! function_exists( 'philosophy_pro_render_work_section' ) ) :
    /**
     * Start work section
     *
     * @return string work section content
     * @since 1.0
     *
     */
    function philosophy_pro_render_work_section( $section_details ) { 
        $options = philosophy_pro_get_theme_options(); // get theme options
        ?>
        <div class="column-wrapper">
            <div class="worker col-3">

                <?php foreach ( $section_details as $content ) : ?>
                    <div class="column-wrapper">
                        <div class="row">
                            <div class="featured-image">
                                <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['img_array'][0] ); ?>" alt="<?php echo esc_attr( $content['title'] ); ?>"></a>
                                <div class="blue-overlay"></div>

                                <div class="hover-content">
                                    <h4><?php echo esc_html( $content['title'] ); ?></h4>
                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="view-more"><span data-hover="<?php esc_html_e( 'Detail', 'philosophy-pro' ); ?>"><?php esc_html_e( 'Detail', 'philosophy-pro' ); ?></span></a>
                                </div><!--.hover-content-->

                            </div><!--.featured-image-->
                        </div><!--.row-->
                    </div><!--.column-wrapper-->
                <?php endforeach; ?>

            </div><!--.worker-->
        </div><!--.column-wrapper-->
    <?php 
    }   
endif;