<?php
/**
 * Theme_Palace options
 *
 * @package Theme_Palace
 * @subpackage Philosophy_Pro
 * @since 1.0
 */

if( !function_exists( 'philosophy_pro_enable_disable_options' ) ) :
    /**
     * Section enable/disable options
     * @return array enable/disable options
     */
    function philosophy_pro_enable_disable_options() {
        $philosophy_pro_enable_disable_options = array(
            'static-frontpage'  => esc_html__( 'Static Frontpage', 'philosophy-pro' ),
            'disabled'          => esc_html__( 'Disabled', 'philosophy-pro' ),
        );

        $output = apply_filters( 'philosophy_pro_enable_disable_options', $philosophy_pro_enable_disable_options );
      
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;

if ( ! function_exists( 'philosophy_pro_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function philosophy_pro_site_layout() {
        $philosophy_pro_site_layout = array(
            'wide'  => esc_html__( 'Wide', 'philosophy-pro' ),
            'boxed' => esc_html__( 'Boxed', 'philosophy-pro' ),
        );

        $output = apply_filters( 'philosophy_pro_site_layout', $philosophy_pro_site_layout );

        return $output;
    }
endif;


if ( ! function_exists( 'philosophy_pro_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function philosophy_pro_sidebar_position() {
        $philosophy_pro_sidebar_position = array(
            'right-sidebar' => esc_html__( 'Right', 'philosophy-pro' ),
            'left-sidebar'  => esc_html__( 'Left', 'philosophy-pro' ),
            'no-sidebar'    => esc_html__( 'No Sidebar', 'philosophy-pro' ),
        );

        $output = apply_filters( 'philosophy_pro_sidebar_position', $philosophy_pro_sidebar_position );

        return $output;
    }
endif;

if ( ! function_exists( 'philosophy_pro_selected_sidebar' ) ) :
    /**
     * Selected sidebar
     * @return array available Sidbar
     */
    function philosophy_pro_selected_sidebar() {
        $philosophy_pro_selected_sidebar = array(
            'sidebar-1'     => esc_html__( 'Default ( Primary Sidebar )', 'philosophy-pro' ),
            'opt-sidebar-1' => esc_html__( 'Optional Sidebar 1', 'philosophy-pro' ),
            'opt-sidebar-2' => esc_html__( 'Optional Sidebar 2', 'philosophy-pro' ),
        );

        $output = apply_filters( 'philosophy_pro_selected_sidebar', $philosophy_pro_selected_sidebar );

        return $output;
    }
endif;

if ( ! function_exists( 'philosophy_pro_header_image' ) ) :
    /**
     * Header image options
     * @return array Header image options
     */
    function philosophy_pro_header_image() {
        $philosophy_pro_header_image = array(
            'enable' => esc_html__( 'Enable( Featured Image )', 'philosophy-pro' ),
            '' => esc_html__( 'Default ( Customizer Header Image )', 'philosophy-pro' ),
        );

        $output = apply_filters( 'philosophy_pro_header_image', $philosophy_pro_header_image );

        return $output;
    }
endif;

if ( ! function_exists( 'philosophy_pro_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function philosophy_pro_pagination_options() {

        $philosophy_pro_pagination_options = array(
            'numeric' => esc_html__( 'Numeric', 'philosophy-pro' ),
            'default' => esc_html__( 'Default(Older/Newer)', 'philosophy-pro' ),
        );

        if ( class_exists( 'Jetpack' ) && Jetpack::is_module_active( 'infinite-scroll' ) ) :
            $philosophy_pro_pagination_options = array(
                'numeric'         => esc_html__( 'Numeric', 'philosophy-pro' ),
                'default'         => esc_html__( 'Default(Older/Newer)', 'philosophy-pro' ),
                'infinite-click'  => esc_html__( 'Infinite Click (Jetpack)', 'philosophy-pro' ),
                'infinite-scroll' => esc_html__( 'Infinite Scroll (Jetpack)', 'philosophy-pro' ),
            );
        endif;

        $output = apply_filters( 'philosophy_pro_pagination_options', $philosophy_pro_pagination_options );

        return $output;
    }
endif;

if( ! function_exists('philosophy_pro_slider_effect') ) :
    /**
     * Slider effects
     * @return array Slider effects
     */
    function philosophy_pro_slider_effect() {
        $philosophy_pro_slider_effect = array(
            'cubic-bezier(0.680, 0, 0.265, 1)'            => esc_html__( 'Default', 'philosophy-pro' ),
            'fade'                                        => esc_html__( 'Fade', 'philosophy-pro' ),
            'cubic-bezier(0.250, 0.250, 0.750, 0.750)'    => esc_html__( 'Linear', 'philosophy-pro' ),
            'cubic-bezier(0.250, 0.100, 0.250, 1.000)'    => esc_html__( 'Ease', 'philosophy-pro' ),
            'cubic-bezier(0.950, 0.050, 0.795, 0.035)'    => esc_html__( 'Cubic', 'philosophy-pro' ),
            'cubic-bezier(0.600, -0.280, 0.735, 0.045)'   => esc_html__( 'Ease In Back', 'philosophy-pro' ),
            'cubic-bezier(0.785, 0.135, 0.150, 0.860)'    => esc_html__( 'EaseInOutCirc', 'philosophy-pro' ),
            'cubic-bezier(0.680, -0.550, 0.265, 1.550)'   => esc_html__( 'EaseInOutBack', 'philosophy-pro' ),
        );

        $output =  apply_filters( 'philosophy_pro_slider_effect', $philosophy_pro_slider_effect );

        // Sort array in ascending order, according to the key:
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;

if( ! function_exists( 'philosophy_pro_header_typography_options' ) ) :
    /**
     * Returns list of header typography
     * @return array header font styles
     */
    function philosophy_pro_header_typography_options(){

        $choices = array(
            'default'       => esc_html__( 'Default', 'philosophy-pro' ),
            'header-font-1' => esc_html__( 'Rajdhani Font', 'philosophy-pro' ),
            'header-font-2' => esc_html__( 'Cherry Swash Font', 'philosophy-pro' ),
            'header-font-3' => esc_html__( 'Philosopher Font', 'philosophy-pro' ),
            'header-font-4' => esc_html__( 'Slabo Font', 'philosophy-pro' ),
            'header-font-5' => esc_html__( 'Dosis Font', 'philosophy-pro' ),
        );

        $output = apply_filters( 'philosophy_pro_header_typography_options', $choices );
        if ( ! empty( $output ) ) {
          ksort( $output );
        }
        return $output;
    }
endif;

if( !function_exists( 'philosophy_pro_body_typography_options' ) ) :
    /**
     * Returns list of header typography
     * @return array header font styles
     */
    function philosophy_pro_body_typography_options(){

        $choices = array(
          'default'     => esc_html__( 'Default', 'philosophy-pro' ),
          'body-font-1' => esc_html__( 'News Cycle Font', 'philosophy-pro' ),
          'body-font-2' => esc_html__( 'Pontano Sans Font', 'philosophy-pro' ),
          'body-font-3' => esc_html__( 'Gudea Font', 'philosophy-pro' ),
          'body-font-4' => esc_html__( 'Quattrocento Font', 'philosophy-pro' ),
          'body-font-5' => esc_html__( 'Khand Font', 'philosophy-pro' ),
          'body-font-7' => esc_html__( 'Raleway Font', 'philosophy-pro' ),
        );
        $output = apply_filters( 'philosophy_pro_body_typography_options', $choices );
        if ( ! empty( $output ) ) {
          ksort( $output );
        }
        return $output;

    }
endif;

if( ! function_exists( 'philosophy_pro_theme_color' ) ) :
    /**
     * Theme Color
     * @return array site theme color options
     */
    function philosophy_pro_theme_color() {
        $philosophy_pro_theme_color = array(
            'blue'   => esc_html__( 'Blue', 'philosophy-pro' ),
            'red'    => esc_html__( 'Red', 'philosophy-pro' ),
            'green'  => esc_html__( 'Green', 'philosophy-pro' ),
            'yellow' => esc_html__( 'Yellow', 'philosophy-pro' ),
            'black'  => esc_html__( 'Black', 'philosophy-pro' ),
        );

        $output = apply_filters( 'philosophy_pro_theme_color', $philosophy_pro_theme_color );

        return $output;
    }
endif;